<?xml version="1.0"?>
<!-- in case of any change in xsl/xml file modify all connected xsl and xml files from this package  -->

<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://icl.com/saxon" xmlns:textutil="textutil" xmlns:graph="graph" xmlns:results="results" extension-element-prefixes="saxon">
	<xsl:include href="res_metrics.xsl" />
	
    <!-- =================  print standards menu ============================ -->
        
    <xsl:template name="display_standards_menu">
    <xsl:param name="auth"/>
    
    <xsl:variable name="href" saxon:assignable="yes">#cs</xsl:variable>
    <xsl:if test="$auth">    	
    	<saxon:assign name="href" select="concat('#cst_',$auth)"/>
    </xsl:if>
    
    <xsl:if test="($coding_standards) > 0">   
	    <xsl:call-template name="display_linked_menu_item">
	     <xsl:with-param name="text" select="$RES_PARAMETER_CODING_STANDARDS" />
	     <xsl:with-param name="link" select="$href" />
	    </xsl:call-template>
    </xsl:if>
    </xsl:template>
    
    <!-- =================  print standards ============================ -->
    
    <xsl:template name="display_standards">
    <!-- print coding standards header -->
    <xsl:if test="($coding_standards) > 0">

    <xsl:call-template name="summary_section_header">
        <xsl:with-param name="ref">cs</xsl:with-param>
        <xsl:with-param name="id">cs_summary_section</xsl:with-param>
        <xsl:with-param name="label" select="$RES_PARAMETER_SUMMARY_STATIC_ANALYSIS"/>      
    </xsl:call-template>

    <xsl:call-template name="cs_summary_charts"/>

    <xsl:call-template name="collapsible_section_header">
        <xsl:with-param name="id">cs_details_section</xsl:with-param>
		<xsl:with-param name="label" select="$RES_PARAMETER_DETAILS_STATIC_ANALYSIS"/>		
    </xsl:call-template>
	           
    <div id="cs_details_section">
    <xsl:call-template name="cs_header"/>

    <!-- print coding standards summary -->
    <xsl:if test="($generate_graphs = 'true') and ($cs_history) > 0">
    <br/>
    <xsl:call-template name="generate_graph">
       <xsl:with-param name="graph" select="/ResultsSession/CodingStandards/History/Graph[@id=$checkedlines_graph_id]"/>
       <xsl:with-param name="img_name" select="concat('standard_',$org_time)"/>
    </xsl:call-template>
    </xsl:if>
    
    
    <br/>
            <xsl:if test="($report_format_mode='text')">
                <xsl:call-template name="cs_summary_text"/>
            </xsl:if>
            <xsl:if test="not($report_format_mode='text')">
                <xsl:call-template name="cs_summary"/>
            </xsl:if>
            
            
            <!-- coding standards summary -->
            
            <xsl:if test="($cs_rules) > 0 and ($cs_errors_nmb) > 0">
                <br/>
                <xsl:call-template name="cs_error_summary"/>
            </xsl:if>
            
            <br/>
            
        	<xsl:if test="not($report.mail.compact = $trends) or not(($report_type) = ($email_report))">
           
            <xsl:if test="($report.authors_details) = 'true'">
                
                <xsl:if test="($cs_errors_nmb) > 0 or ($cs_supp_errors_nmb) > 0">
                    <xsl:call-template name="cs_authors_summary"/>
                </xsl:if>
                
                <!-- print coding standards error details for each auth -->
                <br/>
                <xsl:call-template name="summary"/>
            </xsl:if>
            
            <xsl:if test="($report.contexts_details) = 'true'">
                <xsl:if test="not(($report.developer_errors) = 'true')"><br/></xsl:if>
                <xsl:call-template name="standards_tested_files_details"/>        
            </xsl:if>
            
            <xsl:if test="($report.developer_errors) = 'true'">
                <xsl:if test="($report.authors_details) = 'true' or ($report.contexts_details) = 'true'">
                    <br/>
                    <xsl:call-template name="bd_draw_manager_legend"/>
                </xsl:if>
            </xsl:if>
            
            <!-- coding standards active rules list -->
            <xsl:if test="($report.active_rules) = 'true'">
                <xsl:call-template name="cs_active_rules"/>
            </xsl:if>
        </xsl:if>
        <xsl:call-template name="display_metrics"/>
    </div>
	</xsl:if>
    </xsl:template>    
        
    <!-- =================  print standards author details ============================ -->
    
    <xsl:template name="standards_author_details_info">
        <xsl:param name="auth"/>
        <xsl:param name="authid"/>        
        <xsl:param name="authidx"/>
        <xsl:param name="author_cs_errors"/>
        <xsl:param name="author_urgent_cs_errors"/>
        <xsl:param name="author_cs_suppr_msgs"/>
        
        <xsl:variable name="author_cs_history" select="count(/ResultsSession/CodingStandards/History/Graph[@id=$checkedlines_graph_id]/Authors/Author[@name = $auth]/X)"/>
    
    <!-- standard history graph -->
    <xsl:if test="($generate_graphs = 'true') and ($author_cs_history) > 0">
       <xsl:call-template name="generate_graph">
          <xsl:with-param name="graph" select="/ResultsSession/CodingStandards/History/Graph[@id=$checkedlines_graph_id]"/>
          <xsl:with-param name="img_name" select="concat('standard_',$authid,'_',$org_time)"/>
          <xsl:with-param name="auth" select="$auth"/>
       </xsl:call-template>
       <br/>
    </xsl:if>
    
    
    
    <!-- cs summary info -->
    <table width='{$width}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <!-- recommended .... -->
    <tr>
    <td align="left">
    <xsl:if test="($author_urgent_cs_errors) > 0">
        <a class="black_link" href="#cs_urg_{$authid}"><b><xsl:value-of select="$RES_PARAMETER_RECOMMENDED_FINDINGS_TO_ACCOMPLISH"/></b></a>:
    </xsl:if>
    <xsl:if test="not(($author_urgent_cs_errors) > 0)">
        <b><xsl:value-of select="$RES_PARAMETER_RECOMMENDED_FINDINGS_TO_ACCOMPLISH"/></b>:
    </xsl:if>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($author_urgent_cs_errors)"/>
    </td>
    </tr>
    
    <!-- tasks -->
    <tr>
    <td align="left">
        <b><xsl:value-of select="$RES_PARAMETER_FINDINGS"/></b>:
    <!-- total tasks -->    
    <xsl:value-of select="($author_cs_errors)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:if test="($report_type=$email_report) or ($author_cs_errors = $author_urgent_cs_errors)">
        <b><xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/></b>,
    </xsl:if>   
    <xsl:if test="($author_cs_errors > $author_urgent_cs_errors) and not($report_type=$email_report)">
        <a class="black_link" href="#cs_{$auth}"><b><xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/></b></a>,
    </xsl:if>   
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>

    <!-- delta total -->
    <xsl:if test="count(/ResultsSession/CodingStandards/History/Graph[@id=$checkedlines_graph_id]/Authors/Author) > 0">
    <xsl:call-template name="format_author_total_delta">
        <xsl:with-param name="delta" select="/ResultsSession/CodingStandards/History/Graph[@id=$checkedlines_graph_id]/Authors/Author[@name=($auth)]/Delta"/>
    </xsl:call-template>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <b><xsl:value-of select="$RES_PARAMETER_DELTA_TOTAL"/></b>,
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </xsl:if>

    <!-- supp -->   
    <xsl:value-of select="($author_cs_suppr_msgs)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:if test="not($report_type=$email_report) and ($report.suppressed_msgs = 'true') and (($author_cs_suppr_msgs) > 0)">
        <a class="black_link" href="#css_{$auth}"><b><xsl:value-of select="$RES_PARAMETER_SUPPRESSED"/></b></a>
    </xsl:if>
    <xsl:if test="($report_type=$email_report) or not($report.suppressed_msgs = 'true') or not(($author_cs_suppr_msgs) > 0)">
        <b><xsl:value-of select="$RES_PARAMETER_SUPPRESSED"/></b>
    </xsl:if>
    </td>
    </tr>
    <xsl:if test="$goals > 0">
       <tr>
       <td align="left">
          <b><xsl:value-of select="$RES_PARAMETER_GOAL"/></b>:
            <xsl:call-template name="print_goals">
                <xsl:with-param name="violationsList" select="/ResultsSession/CodingStandards/StdViols/*[@auth=($auth)]"/>
            </xsl:call-template>
       </td>
       </tr>
    </xsl:if>
    </table>
    <br/>
    
    
    <xsl:if test="($coding_standards > 0) and ($author_urgent_cs_errors > 0) ">
        <xsl:call-template name="cs_error_author_summary">
        <xsl:with-param name="auth" select="($auth)"/>
        <xsl:with-param name="authidx" select="($authidx)"/>
        <xsl:with-param name="urgent">true</xsl:with-param>
        </xsl:call-template>
        <xsl:if test="not($report.mail.compact = $trends) or not(($report_type) = ($email_report))">
        <br/>
          <table width='{$width}' cellpadding='0' cellspacing='0'>
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">7% 63% 30%</xsl:attribute>
            </xsl:if>     
            <xsl:call-template name="summary_details">
            <xsl:with-param name="auth" select="($auth)"/>
            <xsl:with-param name="authid" select="($authid)"/>
            <xsl:with-param name="mode">single</xsl:with-param>
            <xsl:with-param name="urgent">true</xsl:with-param>
            </xsl:call-template>
          </table>
        </xsl:if>

      <xsl:if test="($coding_standards > 0) and ($author_cs_errors > $author_urgent_cs_errors) and not($report_type=$email_report)">
      <xsl:call-template name="cs_error_author_summary">
      <xsl:with-param name="auth" select="($auth)"/>
      <xsl:with-param name="authidx" select="($authidx)"/>
      </xsl:call-template>
      <br/>
    </xsl:if>
      
    <xsl:if test="($author_cs_errors > $author_urgent_cs_errors and not($report_type=$email_report)) or (not($author_urgent_cs_errors > 0) and ($report.suppressed_msgs = 'true') and ($author_cs_suppr_msgs) > 0)">
      <table width='{$width}' cellpadding='0' cellspacing='0'>
      <xsl:if test="($report_format_mode='pdf')">
          <xsl:attribute name="cols">7% 63% 30%</xsl:attribute>
      </xsl:if>     
      <xsl:call-template name="summary_details">
      <xsl:with-param name="auth" select="($auth)"/>
      <xsl:with-param name="authid" select="($authid)"/>
      <xsl:with-param name="mode">single</xsl:with-param>
      </xsl:call-template>
      </table>
    </xsl:if>

    <xsl:call-template name='bd_draw_developer_legend'>
        <xsl:with-param name='auth' select="$auth"/>
        <xsl:with-param name='param_urgent'><xsl:if test="$report_type=$email_report">true</xsl:if></xsl:with-param>
    </xsl:call-template>
	</xsl:if>
    </xsl:template>
    
    <!-- =================  print coding standards goals data ============================ -->

    <xsl:template name="print_standards_goals_data">

    <xsl:variable name="goal_desc" saxon:assignable="yes"></xsl:variable>
   
    <!-- DON'T PERFORM FINDINGS -->
    <xsl:if test="($cs_goal_mode) = '0'">
        <saxon:assign name="goal_desc"> <xsl:value-of select="$RES_PARAMETER_DONT_PERFORM_FINDINGS"/> </saxon:assign>    
    </xsl:if>
    <!-- ALL FINDINGS -->
    <xsl:if test="($cs_goal_mode) = '1'">
        <saxon:assign name="goal_desc"> <xsl:value-of select="$RES_PARAMETER_ACCOMPLISH_ALL_FINDINGS"/> </saxon:assign>
    </xsl:if>    
    <!-- SUGGEST FINDINGS -->
      <xsl:if test="($cs_goal_mode) = '2'">
       <xsl:if test="not($cs_goal_happy = '0')">
       <saxon:assign name="goal_desc" select="concat($goal_desc,$RES_PARAMETER_GOAL_NO_MORE_THAN,' &lt;b&gt;',$cs_goal_happy,'&lt;/b&gt; ',$RES_PARAMETER_FINDINGS_LOWERCASE)"/>
       </xsl:if>
       <xsl:if test="$cs_goal_happy = '0'">
       <saxon:assign name="goal_desc" select="concat($RES_PARAMETER_GOAL_NO,' ',$RES_PARAMETER_FINDINGS_LOWERCASE)"/>
       </xsl:if>
       <xsl:if test="not($cs_goal_happy_only = 'true') and string-length($cs_goal_date) > 0">
       <saxon:assign name="goal_desc" select="concat($goal_desc,' ',$RES_PARAMETER_GOAL_BY,' &lt;b&gt;',$cs_goal_date,'&lt;/b&gt;')"/>
      </xsl:if>
    </xsl:if>
    
    <xsl:if test="not(string-length($goal_desc) > 0)">
        <saxon:assign name="goal_desc"> <xsl:value-of select="$RES_PARAMETER_ACCOMPLISH_ALL_FINDINGS"/> </saxon:assign>
    </xsl:if>
    <xsl:value-of select="($goal_desc)" disable-output-escaping="yes"/>
    
    </xsl:template>
        
    <!-- =================  print coding standards header ============================ -->
    
    <xsl:template name="cs_header">

    <table class="header" width="{$width}" cellpadding="0" cellspacing="0">
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">15% 70% 15%</xsl:attribute>
        </xsl:if>
        <tr>
           <td width="15%"></td>
           <td align="center">
              <div class="header"><xsl:value-of select="$RES_PARAMETER_CODING_STANDARDS"/></div>
           </td>
           <td width="15%" align="right" valign="bottom">
	  	      <xsl:if test="not($report_type = $email_report) and ($first_back_to_top = 'false')">
                 <xsl:call-template name="back_to_top"/>
              </xsl:if>
   		      <saxon:assign name="first_back_to_top">false</saxon:assign>
           </td>
        </tr>
    </table>
    </xsl:template>
    
    <!-- =================  cs_summary_title ============================ -->
    
    <xsl:template name="cs_summary_title">
    <xsl:param name="urgent"/>
    <xsl:param name="display_mode"/>

    <xsl:variable name="sort_cat" select="concat('javascript:sortByCategory(',$urgent,')')"/>   
    <xsl:variable name="sort_sev" select="concat('javascript:sortBySeverity(',$urgent,')')"/>
    <xsl:variable name="sort_cat_link" select="concat('cs_link_cat',$urgent)"/>     
    <xsl:variable name="sort_sev_link" select="concat('cs_link_sev',$urgent)"/>     
    <tr>
    <td>
    
    <table class="header" width="100%" cellpadding="0" cellspacing="0">
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
        
        <tr>        
        <xsl:if test="($display_mode = 'switch')">
        <td width="30%"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td>
        </xsl:if>

        <td align="center">
            <xsl:if test="not($urgent = 'true')">
                <xsl:if test="($display_mode='cat')">
                <div class="small_header" id="cs_title_cat" style="display:block;">
                    <xsl:value-of select="$RES_PARAMETER_DISTRIBUTION_TOTAL"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_BY_CATEGORY"/>
                </div>
                </xsl:if>        
                <xsl:if test="($display_mode='sev')">
                <div class="small_header" id="cs_title_sev" style="display:block;">
                    <xsl:value-of select="$RES_PARAMETER_DISTRIBUTION_TOTAL"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_BY_SEVERITY"/>
                </div>
                </xsl:if>        
                <xsl:if test="$display_mode='switch'">
                    <div class="small_header" id="cs_title_cat" style="display:block;">    
                        <xsl:value-of select="$RES_PARAMETER_DISTRIBUTION_TOTAL"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_BY_CATEGORY"/>
                    </div><div class="small_header" id="cs_title_sev" style="display:none;">    
                        <xsl:value-of select="$RES_PARAMETER_DISTRIBUTION_TOTAL"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_BY_SEVERITY"/>
                    </div>
                </xsl:if>
            </xsl:if>
            <xsl:if test="($urgent = 'true')">
                <xsl:if test="($display_mode='cat')">
               	<div class="small_header" id="cs_title_cat" style="display:block;">
                    <xsl:value-of select="$RES_PARAMETER_DISTRIBUTION_RECOMMENDED"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_BY_CATEGORY"/>
                </div>
                </xsl:if>
                <xsl:if test="($display_mode='sev')">
                <div class="small_header" id="cs_title_sev" style="display:block;">
                    <xsl:value-of select="$RES_PARAMETER_DISTRIBUTION_RECOMMENDED"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_BY_SEVERITY"/>
                </div>
                </xsl:if>
                <xsl:if test="$display_mode='switch'">
                    <div class="small_header" id="cs_title_cattrue" style="display:block;">    
                        <xsl:value-of select="$RES_PARAMETER_DISTRIBUTION_RECOMMENDED"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_BY_CATEGORY"/>
                    </div><div class="small_header" id="cs_title_sevtrue" style="display:none;">    
                       <xsl:value-of select="$RES_PARAMETER_DISTRIBUTION_RECOMMENDED"/><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="$RES_PARAMETER_BY_SEVERITY"/>
                    </div>
                </xsl:if>
            </xsl:if>
        </td>

        <xsl:if test="($display_mode = 'switch')">
        
        <td align="right" width="30%">
            <xsl:call-template name="standard_link_ref">
                <xsl:with-param name="href" select="($sort_cat)"/>
                <xsl:with-param name="label"><xsl:value-of select="$RES_PARAMETER_CATEGORY"/></xsl:with-param>
                <xsl:with-param name="class">blue_link</xsl:with-param>
                <xsl:with-param name="id" select="($sort_cat_link)"/>
                <xsl:with-param name="email_class">gray</xsl:with-param>
            </xsl:call-template>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            |
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <xsl:call-template name="standard_link_ref">
                <xsl:with-param name="href" select="($sort_sev)"/>
                <xsl:with-param name="label"><xsl:value-of select="$RES_PARAMETER_SEVERITY"/></xsl:with-param>
                <xsl:with-param name="class">blue_link</xsl:with-param>
                <xsl:with-param name="id" select="($sort_sev_link)"/>
                <xsl:with-param name="email_class">gray</xsl:with-param>
            </xsl:call-template>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        </td>    
        </xsl:if>
        </tr>
    </table>
    </td>
    </tr>
    <tr><td>
        <xsl:call-template name="print_header_separator"/>
    </td></tr>
    </xsl:template> 
    
    <!-- =================  print coding standards auth info ============================ -->
    
    <xsl:template name="cs_author_info">
    <xsl:param name="auth"/>
    <xsl:param name="authid"/>

    <xsl:variable name="author_cs_violations" 
        select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true')])"/>
    <xsl:variable name="author_exec_violations" 
        select="count(/ResultsSession/Exec/ExecViols/ExecViol[@auth=($auth)])"/>
    <xsl:variable name="author_tcases" 
        select="count(/ResultsSession/Generation/GenerationInformations/GenerationInfo[@auth=($auth)]/TestCaseList/TestCase)"/>
    <xsl:variable name="author_recommended_errors" 
        select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true') and @urgent='true'])"/>
    <xsl:variable name="author_cs_supp" saxon:assignable="yes">0</xsl:variable>
    <xsl:for-each select="/ResultsSession/CodingStandards/Supps/Supp[@suppAuth=($auth)]">
        <xsl:variable name="ref_id" select="@refId"/>
        <xsl:variable name="suppr_msgs"
            select="count(/ResultsSession/CodingStandards/StdViols/*[@suppRef=($ref_id) and @supp='true'])"/>
        <saxon:assign name="author_cs_supp" select="$author_cs_supp + $suppr_msgs"/>
    </xsl:for-each>
    <xsl:variable name="enable_supp" saxon:assignable="yes">0</xsl:variable>
    <xsl:if test="($report.suppressed_msgs = 'true') and (($author_cs_supp) > 0)">
    <saxon:assign name="enable_supp">1</saxon:assign>
    </xsl:if>    
    <xsl:variable name="author_all_tasks" select="($author_cs_violations) + ($author_tcases) + ($author_exec_violations)"/>
     
    <!--
    <option value="#cs_{$auth}"><xsl:value-of select="($auth)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    [<xsl:value-of select="($author_cs_violations)"/>]</option>
    -->
    <tr class="alternating">
    <td class="singleborder right_separator" align="left">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       <xsl:call-template name="standards_author_link">
          <xsl:with-param name="auth" select="($auth)"/>
          <xsl:with-param name="authid" select="($authid)"/>
          <xsl:with-param name="hasAuthorRecommendedTasks" select="boolean($author_recommended_errors > 0)"/>
          <xsl:with-param name="hasAuthorTasks" select="boolean($author_all_tasks > 0)"/>
          <xsl:with-param name="hasAuthorSuppressions" select="boolean($enable_supp > 0)"/>
       </xsl:call-template>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>   
    
    <td class="singleborder" align="center">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($author_cs_supp)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>   
    <xsl:if test="count(/ResultsSession/CodingStandards/History/Graph[@id=$checkedlines_graph_id]/Authors/Author) > 0">
    <td class="singleborder" align="center">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    
    <xsl:call-template name="format_author_total_delta">
        <xsl:with-param name="delta" select="/ResultsSession/CodingStandards/History/Graph[@id=$checkedlines_graph_id]/Authors/Author[@name=($auth)]/Delta"/>
    </xsl:call-template>
    
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>   
    </xsl:if>
    <td class="singleborder" align="center">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($author_cs_violations)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>   
    <td class="singleborder" align="center">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($author_recommended_errors)"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>   
    </tr>
    <!-- TODO remove? /xsl:if -->
    </xsl:template> 
    
    <!-- =================  print coding standards auth list ============================ -->
    
    <xsl:template name="cs_author_list">
        <xsl:for-each select="/ResultsSession/Authors/Author">        
            <xsl:call-template name="cs_author_info">
                <xsl:with-param name="auth" select="@name"/>
                <xsl:with-param name="authid" select="@id"/>
            </xsl:call-template>
            
       </xsl:for-each> 
    </xsl:template>     
    
    <!-- =================  cs_authors_summary ============================ -->
    
    <xsl:template name="cs_authors_summary">
    
    <xsl:variable name="author_cs_history" select="count(/ResultsSession/CodingStandards/History/Graph[@id=$checkedlines_graph_id]/Authors/Author)"/>
    
    <xsl:call-template name="authors_header"/>    
    
    <table align="center" class="singleborder" width='{$authors_width}' cellpadding='0' cellspacing='0'>
        
        <xsl:if test="$author_cs_history > 0">
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">52% 12% 12% 12% 12%</xsl:attribute>
            </xsl:if>
        </xsl:if>
        <xsl:if test="$author_cs_history = 0">
            <xsl:if test="($report_format_mode='pdf')">
                 <xsl:attribute name="cols">50% 17% 17% 16%</xsl:attribute>
            </xsl:if>
        </xsl:if>
    <tr bgcolor="{$cs_bcolor}">
    <td class="singleborder right_separator" width="50%" align="center">
        <b><xsl:value-of select="$RES_PARAMETER_AUTHOR"/></b>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    <xsl:if test="$author_cs_history = 0">
    	<td class="singleborder" colspan="3" align='center'>
        	<b><xsl:value-of select="$RES_PARAMETER_FINDINGS"/></b>        	        
    	</td>                
    </xsl:if>
    <xsl:if test="$author_cs_history > 0">
    	<td class="singleborder" colspan="4" align='center'>
        	<b><xsl:value-of select="$RES_PARAMETER_FINDINGS"/></b>
    	</td>       
    </xsl:if>
    </tr>
        <tr bgcolor="{$cs_bcolor}">
            <td class="singleborder right_separator" align="center">
            <span style="zoom:1;"/>
            </td>
            <td class="singleborder" align="center">
                <xsl:value-of select="$RES_PARAMETER_SUPPRESSED"/>
            </td>
            <xsl:if test="$author_cs_history > 0">
                <td class="singleborder" align="center">
                    <xsl:value-of select="$RES_PARAMETER_DELTA_TOTAL"/>
                </td>
            </xsl:if>
            <td class="singleborder" align="center">
                <xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/>
            </td>                       
            <td class="singleborder" align="center">
                <xsl:value-of select="$RES_PARAMETER_RECOMMENDED"/>
            </td>
        </tr>
    <xsl:call-template name="cs_author_list"/>
    </table>
    </xsl:template> 
    
    <!-- =================  print details of errors ============================ -->
    
    <xsl:template name="summary_details">
    <xsl:param name="auth"/>
    <xsl:param name="authid"/>
    <xsl:param name="mode"/>
    <xsl:param name="urgent"/>

    <xsl:call-template name="summary_details_by_file">
    <xsl:with-param name="auth"  select="$auth"/>
    <xsl:with-param name="authid"  select="$authid"/>
    <xsl:with-param name="mode"  select="$mode"/>
    <xsl:with-param name="urgent"  select="$urgent"/>
    </xsl:call-template>
    </xsl:template> 
    
    <!-- =================  print summary ============================ -->
    
    <xsl:template name="summary">
        <xsl:for-each select="/ResultsSession/Authors/Author">
            <xsl:variable name="author" select="@name"/>
            
            <xsl:if test="($report.developer_errors) = 'true'">
                <table width='{$width}' cellpadding='0' cellspacing='0'>
                    <xsl:if test="($report_format_mode='pdf')">
                        <xsl:attribute name="cols">7% 63% 30%</xsl:attribute>
                    </xsl:if>

                    <xsl:call-template name="summary_details">
                        <xsl:with-param name="auth" select="$author"/>
                        <xsl:with-param name="authid" select="@id"/>
                        <xsl:with-param name="mode">summary</xsl:with-param>
                    </xsl:call-template>
                </table>
            </xsl:if>
            <xsl:variable name="author_cs_suppr_msgs" saxon:assignable="yes">0</xsl:variable>
            <xsl:for-each select="/ResultsSession/CodingStandards/Supps/Supp[@suppAuth=($author)]">
                <xsl:variable name="ref_id" select="@refId"/>
                <xsl:variable name="suppr_msgs"
                    select="count(/ResultsSession/CodingStandards/StdViols/*[@suppRef=($ref_id) and @supp='true'])"/>
                <saxon:assign name="author_cs_suppr_msgs" select="$author_cs_suppr_msgs + $suppr_msgs"/>
            </xsl:for-each>
            <xsl:if test="($report.suppressed_msgs = 'true') and ($author_cs_suppr_msgs) > 0">
                <xsl:call-template name="supp_messages">
                    <xsl:with-param name="auth" select="@name"/>
                    <xsl:with-param name="authid" select="@id"/>
                </xsl:call-template>
            </xsl:if>
       </xsl:for-each> 
    </xsl:template>         

	<!-- =================  print standards summary statistics ============= -->
    
    <xsl:template name="cs_summary_stats">
       <xsl:param name="auth"/>
       
       <xsl:variable name="total" saxon:assignable="yes">0</xsl:variable>
       <xsl:variable name="label" saxon:assignable="yes"></xsl:variable>
       
       <xsl:if test="string-length($auth) > 0">
       
         <xsl:variable name="author_cs_errors" select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true')])"/>
         <xsl:variable name="author_urgent_cs_errors" select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true') and @urgent='true'])"/>
         
         <!--xsl:if test="not(($author_urgent_cs_errors) > 0)">
             <saxon:assign name="total" select="$author_cs_errors"/>
             <saxon:assign name="label" select="concat($RES_PARAMETER_TOTAL_FINDINGS,': ')"/>
         </xsl:if>    
         <xsl:if test="($author_urgent_cs_errors) > 0"-->
             <saxon:assign name="total" select="$author_urgent_cs_errors"/>
             <saxon:assign name="label" select="concat($RES_PARAMETER_RECOMMENDED_FINDINGS,': ')"/>
         <!--/xsl:if-->
       </xsl:if>    
       
       <xsl:if test="string-length($auth) = 0">
         <xsl:variable name="severityStats" saxon:assignable="yes" select="/ResultsSession/CodingStandards/Rules/SeverityList/Severity[@id='1']"/>
         <saxon:assign name="total" select="$severityStats/@total"/>
         <saxon:assign name="label" select="concat($RES_PARAMETER_SEVERITY,' 1 ',$RES_PARAMETER_FINDINGS,': ')"/>
       </xsl:if>

       <xsl:if test="(string-length($total) = 0)">
         <saxon:assign name="total" select="0"/>
       </xsl:if>

       <xsl:value-of select="$label"/><xsl:value-of select="$total"/>

    </xsl:template>

    <!-- =================  print standards summary charts ============= -->
    
    <xsl:template name="cs_summary_charts">
       
       <xsl:variable name="severityOneStats" saxon:assignable="yes" select="/ResultsSession/CodingStandards/Rules/SeverityList/Severity[@id='1']"/>
       <xsl:variable name="severityTwoStats" saxon:assignable="yes" select="/ResultsSession/CodingStandards/Rules/SeverityList/Severity[@id='2']"/>
       <xsl:variable name="severityThreeStats" saxon:assignable="yes" select="/ResultsSession/CodingStandards/Rules/SeverityList/Severity[@id='3']"/>
       <xsl:variable name="severityFourStats" saxon:assignable="yes" select="/ResultsSession/CodingStandards/Rules/SeverityList/Severity[@id='4']"/>
       <xsl:variable name="severityFiveStats" saxon:assignable="yes" select="/ResultsSession/CodingStandards/Rules/SeverityList/Severity[@id='5']"/>

       <xsl:variable name="sev_1_total" saxon:assignable="yes" select="$severityOneStats/@total"/>    
       <xsl:if test="string-length($sev_1_total) = 0">
           <saxon:assign name="sev_1_total" select="0"/>
       </xsl:if>
                              
       <xsl:variable name="sev_2_total" saxon:assignable="yes" select="$severityTwoStats/@total"/>    
       <xsl:if test="string-length($sev_2_total) = 0">
           <saxon:assign name="sev_2_total" select="0"/>
       </xsl:if>

       <xsl:variable name="sev_3_total" saxon:assignable="yes" select="$severityThreeStats/@total"/>    
       <xsl:if test="string-length($sev_3_total) = 0">
           <saxon:assign name="sev_3_total" select="0"/>
       </xsl:if>

       <xsl:variable name="sev_4_total" saxon:assignable="yes" select="$severityFourStats/@total"/>    
       <xsl:if test="string-length($sev_4_total) = 0">
           <saxon:assign name="sev_4_total" select="0"/>
       </xsl:if>

       <xsl:variable name="sev_5_total" saxon:assignable="yes" select="$severityFiveStats/@total"/>    
       <xsl:if test="string-length($sev_5_total) = 0">
           <saxon:assign name="sev_5_total" select="0"/>
       </xsl:if>

       <xsl:variable name="total" select="$sev_1_total+$sev_2_total+$sev_3_total+$sev_4_total+$sev_5_total"/>                           
    
       <xsl:call-template name="generate_ring_chart_with_legend">
          <xsl:with-param name="title"><xsl:value-of select="$RES_PARAMETER_FINDINGS"/></xsl:with-param>
          <xsl:with-param name="central_text"></xsl:with-param>
          <xsl:with-param name="bottom_text"><xsl:value-of select="concat($RES_PARAMETER_TOTAL_FINDINGS,': ',$total)" /></xsl:with-param>
          <xsl:with-param name="item_names">1,2,3,4,5</xsl:with-param>
          <xsl:with-param name="item_colors"><xsl:value-of 
              select="$sev_1_color"/>,<xsl:value-of
              select="$sev_2_color"/>,<xsl:value-of
              select="$sev_3_color"/>,<xsl:value-of
              select="$sev_4_color"/>,<xsl:value-of
              select="$sev_5_color"/></xsl:with-param>
         <xsl:with-param name="item_data"><xsl:value-of 
              select="$sev_1_total"/>,<xsl:value-of
              select="$sev_2_total"/>,<xsl:value-of
              select="$sev_3_total"/>,<xsl:value-of
              select="$sev_4_total"/>,<xsl:value-of
              select="$sev_5_total"/></xsl:with-param>
          <xsl:with-param name="names_title"><xsl:value-of select="$RES_PARAMETER_SEVERITY"/></xsl:with-param>
          <xsl:with-param name="data_title"><xsl:value-of select="$RES_PARAMETER_NUM_OF_FINDINGS"/></xsl:with-param>
          <xsl:with-param name="img_name" select="concat('standard_summary_',$org_time)"/>
       </xsl:call-template>
       
    </xsl:template>
	    
    <!-- =================  summary_details_by_file ============================ -->
    
    <xsl:template name="summary_details_by_file">
    <xsl:param name="auth"/>
    <xsl:param name="authid"/>
    <xsl:param name="mode"/>
    <xsl:param name="urgent"/>
    
    <xsl:variable name="totErrs" select="tmp" saxon:assignable="yes"/>
    <xsl:if test="not(($urgent) = 'true')">
    <saxon:assign name="totErrs" select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true')])"/>
    </xsl:if>
    <xsl:if test="($urgent) = 'true'">
    <saxon:assign name="totErrs" select="count(/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true') and @urgent='true'])"/>
    </xsl:if>
    <xsl:variable name="supp_msgs" saxon:assignable="yes">0</xsl:variable>
    <xsl:for-each select="/ResultsSession/CodingStandards/Supps/Supp[@suppAuth=($auth)]">
        <xsl:variable name="ref_id" select="@refId"/>
        <xsl:variable name="single_suppr_msgs"
            select="count(/ResultsSession/CodingStandards/StdViols/*[@suppRef=($ref_id) and @supp='true'])"/>
        <saxon:assign name="supp_msgs" select="$supp_msgs + $single_suppr_msgs"/>
    </xsl:for-each>

    <xsl:if test="($totErrs > 0)">
	<xsl:variable name="anchor" saxon:assignable="yes" select="concat('cs_urg_',$authid)"/>
   	<xsl:variable name="message" select="$RES_PARAMETER_RECOMMENDED_FINDINGS_TO_ACCOMPLISH" saxon:assignable="yes"/>    		    	
    <xsl:if test="not(($urgent) = 'true')">
    	<saxon:assign name="anchor" select="concat('cs_',$authid)"/>
    	<saxon:assign name="message" select="$RES_PARAMETER_TOTAL_FINDINGS"/>
    </xsl:if>
    <tr>     				   
    	<xsl:call-template name="details_table_auth_header">
    		<xsl:with-param name="auth" select="$auth"/>
    		<xsl:with-param name="anchor" select="$anchor"/>
    		<xsl:with-param name="number" select="$totErrs"/>
    		<xsl:with-param name="message" select="$message"/>    		    		
   	  	</xsl:call-template>   	  	   	  	   	    	    	    	
    </tr>
    <tr><td colspan="3">
       <xsl:call-template name="print_header_separator"/>
    </td></tr>   
    <tr>
    <td colspan="3" align="left">
    <table width="100%" bgcolor="#FFFFFF" class="doubleborder" cellpadding="0" cellspacing="0">
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">1% 5% 64% 30%</xsl:attribute>
    </xsl:if> 
    
    <xsl:variable name="tmp_file_name" select="empty" saxon:assignable="yes"/>    
    <xsl:for-each select="/ResultsSession/CodingStandards/StdViols/*[@auth=($auth) and not(@supp='true')]">
    <xsl:variable name="fileName" select="@resFile" saxon:assignable="yes"/>    
    
    <xsl:if test="string-length(@locFile) > 0">
        <saxon:assign name="fileName" select="@locFile"/>
    </xsl:if>     
    <xsl:if test="string-length(@uri) > 0">
        <saxon:assign name="fileName" select="@uri"/>
    </xsl:if>     
    
    <xsl:variable name="urgent_err" select="@urgent"/>
    <xsl:variable name="rule" select="@rule"/>
    <xsl:variable name="sev" select="@sev"/>

    <xsl:if test="($urgent = 'true' and $urgent_err = 'true') or not($urgent = 'true')">
    
    <xsl:if test="not($tmp_file_name = $fileName)">            
    <tr>
    <td style="padding-right:10px;padding-left:10px" colspan="4" class="tree">
    <b><xsl:value-of select="($fileName)"/></b>
    </td>
    </tr>
    </xsl:if>
    <xsl:variable name="violationID" saxon:assignable="yes"/>
    <saxon:assign name="violationID">
        <xsl:text>authViolId</xsl:text>
        <xsl:value-of select="$globalViolationIndex"/>
        <saxon:assign name="globalViolationIndex" select="$globalViolationIndex+ 1"/>
    </saxon:assign>
    <tr>
    <xsl:if test="((local-name()='FlowViol') or (local-name()='DupViol')) and not(($report_type) = ($email_report))">
        <xsl:attribute name="id"><xsl:value-of select="($violationID)"/>H</xsl:attribute>
        <xsl:attribute name="style">cursor:pointer</xsl:attribute>
        <xsl:attribute name="onclick">javascript:expandViolaion(&#39;<xsl:value-of select="($violationID)"/>H&#39;,&#39;<xsl:value-of select="($violationID)"/>&#39;, &#39;0&#39;)</xsl:attribute>
    </xsl:if>
         
    <td width="1%" align="right" class="tree" >
        <xsl:if test="(local-name()='FlowViol' or local-name()='DupViol') and not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <font class="gray"><span>+</span></font>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        </xsl:if>
    </td>
    <td width="2%" align="right" valign="top" class="tree">
    <xsl:variable name="ln" select="@ln"/>
    <xsl:if test="not($ln = '-1')"> 
        <font class="gray"><xsl:value-of select="($ln)"/>:</font>
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </xsl:if>
    </td><td valign="top" class="tree"> 
    
    <span style="white-space: pre-wrap;">
    <xsl:variable name="msg" select="@msg"/>
    <xsl:choose>
	    <xsl:when test="string-length($msg) > 2000">
		    <xsl:value-of select="substring($msg, 1, 2000)"/> (...)
		</xsl:when>
		<xsl:otherwise>
		    <xsl:value-of select="$msg"/>
	    </xsl:otherwise>
    </xsl:choose>
    </span>
    
    <xsl:variable name="rev" select="@rev"/>
    <xsl:if test="(string-length($rev) > 0) and not($rev = 'unknown.revision')">
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <font class="gray"><xsl:value-of select="$RES_PARAMETER_REVISION"/></font>
        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <font class="gray"><xsl:value-of select="($rev)"/></font>
    </xsl:if>
    </td>
    <td style="white-space: nowrap; padding-right:10px;" align="right" valign="top" class="tree">
       <xsl:call-template name="standards_rule_link">
          <xsl:with-param name="rule" select="($rule)"/>
          <xsl:with-param name="sev" select="($sev)"/>
       </xsl:call-template>
    </td>
    </tr>
    <xsl:if test="(local-name()='DupViol')">
      <xsl:call-template name="dup_path">
         <xsl:with-param name="checkedFilesStyle">false</xsl:with-param>
          <xsl:with-param name="violationID" select="$violationID"/>
      </xsl:call-template>
    </xsl:if>

    <xsl:if test="local-name()='FlowViol'">        
       <xsl:variable name="position" saxon:assignable="yes"></xsl:variable>       
       <xsl:call-template name="bd_dump_path">
          <xsl:with-param name="checkedFilesStyle">false</xsl:with-param>
          <xsl:with-param name="violationID" select="$violationID"/>
       </xsl:call-template>

    </xsl:if>
            
    <saxon:assign name="tmp_file_name" select="$fileName"/>
    
    </xsl:if>   

    </xsl:for-each>
    </table>
    </td>
    </tr>
    </xsl:if>
    <xsl:if test="($totErrs > 0)">
    <tr>
    <td colspan="3"><br/></td>
    </tr>
    </xsl:if>

    </xsl:template> 
        
    <!-- =================  print auth coding standards summary errors ============================ -->
    
    <xsl:template name="cs_error_author_summary">
    <xsl:param name="auth"/>
    <xsl:param name="authidx"/>
    <xsl:param name="urgent"/>
    <table width='{$width}' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>

    <xsl:variable name="catSevDisplayMode" saxon:assignable="yes">switch</xsl:variable>
    <xsl:variable name="sevDisplayStyle" saxon:assignable="yes">display:none;</xsl:variable>
    <xsl:if test="(($report_type) = ($email_report)) or ($report_format_mode = 'pdf')">
        <saxon:assign name="catSevDisplayMode">sequential</saxon:assign>
        <saxon:assign name="sevDisplayStyle">display:block;</saxon:assign>
    </xsl:if>
    
    <xsl:if test="($catSevDisplayMode = 'switch')">
       <xsl:call-template name="cs_summary_title">
          <xsl:with-param name="display_mode">switch</xsl:with-param>
          <xsl:with-param name="urgent" select="($urgent)"/>
       </xsl:call-template>
    </xsl:if>
    <xsl:if test="($catSevDisplayMode = 'sequential')">
        <xsl:call-template name="cs_summary_title">
          <xsl:with-param name="urgent" select="($urgent)"/>
          <xsl:with-param name="display_mode">cat</xsl:with-param>
        </xsl:call-template>
    </xsl:if>

    <tr>    
    <td align="left">
    
    <xsl:variable name="id_cat" select="concat('cs_cat', $urgent)"/>    
    <div id="{$id_cat}" style="display:block;">
    <table class="doubleborder" width='100%' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <xsl:variable name="catList" select="/ResultsSession/CodingStandards/Rules/CategoriesList//Category"/>
    <saxon:assign name="isFirstRow">true</saxon:assign>

    <xsl:for-each select="$catList">
    <xsl:call-template name="cstandard">
    <xsl:with-param name="cat" select="@name"/>
    <xsl:with-param name="desc" select="@desc"/>
    <xsl:with-param name="auth" select="($auth)"/>
    <xsl:with-param name="authidx" select="($authidx)"/>
    <xsl:with-param name="urgent" select="($urgent)"/>
    </xsl:call-template>
    </xsl:for-each>
    </table>
    </div>
    </td></tr>
    <xsl:if test="($catSevDisplayMode = 'sequential')">
        <xsl:call-template name="cs_summary_title">
          <xsl:with-param name="urgent" select="($urgent)"/>
          <xsl:with-param name="display_mode">sev</xsl:with-param>
        </xsl:call-template>
    </xsl:if>
    <tr><td align="left">
        <xsl:variable name="id_sev" select="concat('cs_sev', $urgent)"/>    
	    <div id="{$id_sev}" style="{$sevDisplayStyle}">
	    <table width='100%' class="doubleborder" cellpadding='0' cellspacing='0'>
	        <xsl:if test="($report_format_mode='pdf')">
	            <xsl:attribute name="cols">100%</xsl:attribute>
	        </xsl:if>
	    <xsl:call-template name="cstandard_sev">
	    <xsl:with-param name="sev">1</xsl:with-param>
	    <xsl:with-param name="sevlabel"><xsl:value-of select="$RES_PARAMETER_SEVERITY_1"/></xsl:with-param>
	    <xsl:with-param name="auth" select="($auth)"/>
	    <xsl:with-param name="authidx" select="($authidx)"/>
	    <xsl:with-param name="urgent" select="($urgent)"/>
	    </xsl:call-template>
	    <xsl:call-template name="cstandard_sev">
	    <xsl:with-param name="sev">2</xsl:with-param>
	    <xsl:with-param name="sevlabel"><xsl:value-of select="$RES_PARAMETER_SEVERITY_2"/></xsl:with-param>
	    <xsl:with-param name="auth" select="($auth)"/>
	    <xsl:with-param name="authidx" select="($authidx)"/>
	    <xsl:with-param name="urgent" select="($urgent)"/>
	    </xsl:call-template>
	    <xsl:call-template name="cstandard_sev">
	    <xsl:with-param name="sev">3</xsl:with-param>
	    <xsl:with-param name="sevlabel"><xsl:value-of select="$RES_PARAMETER_SEVERITY_3"/></xsl:with-param>
	    <xsl:with-param name="auth" select="($auth)"/>
	    <xsl:with-param name="authidx" select="($authidx)"/>
	    <xsl:with-param name="urgent" select="($urgent)"/>
	    </xsl:call-template>
	    <xsl:call-template name="cstandard_sev">
	    <xsl:with-param name="sev">4</xsl:with-param>
	    <xsl:with-param name="sevlabel"><xsl:value-of select="$RES_PARAMETER_SEVERITY_4"/></xsl:with-param>
	    <xsl:with-param name="auth" select="($auth)"/>
	    <xsl:with-param name="authidx" select="($authidx)"/>
	    <xsl:with-param name="urgent" select="($urgent)"/>
	    </xsl:call-template>
	    <xsl:call-template name="cstandard_sev">
	    <xsl:with-param name="sev">5</xsl:with-param>
	    <xsl:with-param name="sevlabel"><xsl:value-of select="$RES_PARAMETER_SEVERITY_5"/></xsl:with-param>
	    <xsl:with-param name="auth" select="($auth)"/>
	    <xsl:with-param name="authidx" select="($authidx)"/>
	    <xsl:with-param name="urgent" select="($urgent)"/>
	    </xsl:call-template>
	    </table>
	    </div>
    </td></tr>
    </table>
    </xsl:template>
    
    <!-- =================  print coding standards summary errors ============================ -->
    
    <xsl:template name="cs_summary">
        <table width="{$width}" cellpadding="0" cellspacing="0">
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">100%</xsl:attribute>
            </xsl:if>
            <tr>
                <td width="80%">
                    <table width="100%" class="singleborder" cellpadding="0" cellspacing="0">
                        <xsl:if test="($report_format_mode='pdf')">
                            <xsl:if test="($process_quick_fixes = 'true')">
                                <xsl:attribute name="cols">36% 8% 8% 8% 8% 8% 8% 8% 8%</xsl:attribute>
                            </xsl:if>
                            <xsl:if test="not($process_quick_fixes = 'true')">
                                <xsl:attribute name="cols">37% 9% 9% 9% 9% 9% 9% 9%</xsl:attribute>
                            </xsl:if>
                            
                        </xsl:if>
                        <tr>
                            <td class="singleborder right_separator" width="40%" align="center" bgcolor="{$cs_bcolor}">
                                <b><xsl:value-of select="$RES_PARAMETER_MODULE"/></b>
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                            </td>
                            
                            <xsl:if test="($process_quick_fixes = 'true')">
                                <td class="singleborder  right_separator" align="center" bgcolor="{$cs_bcolor}" colspan="4">
                                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                    <b><xsl:value-of select="$RES_PARAMETER_FINDINGS"/></b>
                                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>                                
                                </td>
                            </xsl:if>
                            <xsl:if test="not($process_quick_fixes = 'true')">
                                <td class="singleborder  right_separator" align="center" bgcolor="{$cs_bcolor}" colspan="3">
                                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                    <b><xsl:value-of select="$RES_PARAMETER_FINDINGS"/></b>
                                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>                                
                                </td>
                            </xsl:if>
                                                        
                            <td class="singleborder right_separator" align="center" bgcolor="{$cs_bcolor}" colspan="2">
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                <b><xsl:value-of select="$RES_PARAMETER_FILES"/></b>
                            </td>                                
                            <td class="singleborder" align="center" bgcolor="{$cs_bcolor}" colspan="2">
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                <b><xsl:value-of select="$RES_PARAMETER_LINES"/></b>
                            </td>                                
                        </tr>
                        <tr>
                        	<td class="singleborder right_separator" align="center" bgcolor="{$cs_bcolor}">
                        	<span style="zoom:1;"/>                                
                            </td>
                            <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                <xsl:value-of select="$RES_PARAMETER_SUPP"/>
                            </td>
                            <xsl:if test="($process_quick_fixes = 'true')">
                                <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                    <xsl:value-of select="$RES_PARAMETER_QFIX"/>
                                </td>
                            </xsl:if>
                            <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                <xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/>
                            </td>
                            <td class="singleborder right_separator" align="center" bgcolor="{$cs_bcolor}">
                                <xsl:value-of select="$RES_PARAMETER_PER"/>
                            </td>
                            <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                <xsl:value-of select="$RES_PARAMETER_CHECKED"/>
                            </td>
                            <td class="singleborder right_separator" align="center" bgcolor="{$cs_bcolor}">
                                <xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/>
                            </td>
                            <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                <xsl:value-of select="$RES_PARAMETER_CHECKED"/>
                            </td>
                            <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                <xsl:value-of select="$RES_PARAMETER_TOTAL_LOWERCASE"/>
                            </td>
                        </tr>
                        <xsl:variable name="total_time" select="/ResultsSession/CodingStandards/@time"/>
                        <xsl:variable name="tchecked_lines" saxon:assignable="yes">0</xsl:variable>
                        <xsl:variable name="ttotLns" saxon:assignable="yes">0</xsl:variable>
                        <xsl:variable name="tchecked_files" saxon:assignable="yes">0</xsl:variable>
                        <xsl:variable name="ttotFiles" saxon:assignable="yes">0</xsl:variable>
                        <xsl:for-each select="/ResultsSession/CodingStandards/Projects/Project">
                        	<xsl:sort select="@name"/>
                            <xsl:variable name="project_name" select="@name"/>
                            <tr class="alternating">
                                <!-- project -->
                                <td class="singleborder right_separator" align="left">
                                    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                    <xsl:value-of select="($project_name)"/>
                                </td>
                                <xsl:variable name="totErrs" select="@totErrs"/>
                                <xsl:variable name="qfixErrs" select="@qfixErrs"/>
                                <!-- errors -->                                
                                            <td class="singleborder" align="center" >
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <xsl:value-of select="@suppErrs"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>
                                            
                                            <xsl:if test="($process_quick_fixes = 'true')">
                                            <td class="singleborder" align="center" >
                                                <xsl:value-of select="@qfixErrs"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>
                                            
                                            </xsl:if>
                                            <td class="singleborder" align="center" >
                                                <xsl:value-of select="$totErrs"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>
                                            
                                            <xsl:variable name="checkedLns" select="@checkedLns"/>
                                            <xsl:variable name="errs" saxon:assignable="yes">0</xsl:variable>
                                            <xsl:if test="($checkedLns) > 0">
                                                <saxon:assign name="errs" select="floor((10000 * $totErrs) div $checkedLns)"/>
                                            </xsl:if>
                                            <td class="singleborder right_separator" align="center" >
                                                <xsl:value-of select="$errs"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>
                                <!-- files -->
                                <xsl:variable name="cchecked_files" select="@checkedFiles"/>
                                <xsl:variable name="ctotFiles" select="@totFiles"/>
                                <saxon:assign name="tchecked_files" select="$tchecked_files + $cchecked_files"/>
                                <saxon:assign name="ttotFiles" select="$ttotFiles + $ctotFiles"/>

                                    
                                            <td class="singleborder" align="center">
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <xsl:value-of select="($cchecked_files)"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>                                            
                                            <td class="singleborder  right_separator" align="center">
                                                <xsl:value-of select="($ctotFiles)"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>

                                <!-- lines -->
                                <xsl:variable name="cchecked_lines" select="@checkedLns"/>
                                <xsl:variable name="ctotLns" select="@totLns"/>
                                <saxon:assign name="tchecked_lines" select="$tchecked_lines + $cchecked_lines"/>
                                <saxon:assign name="ttotLns" select="$ttotLns + $ctotLns"/>

                                            <td class="singleborder" align="center">
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                                <xsl:value-of select="($cchecked_lines)"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>                                            
                                            <td class="singleborder" align="center">
                                                <xsl:value-of select="($ctotLns)"/>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>

                            </tr>
                        </xsl:for-each>
                        <tr>
                            <!-- total time, problem -->
                            <td class="singleborder  right_separator" align="left" bgcolor="{$cs_bcolor}">
                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                <b><xsl:value-of select="$RES_PARAMETER_TOTAL"/></b> [<xsl:value-of select="($total_time)"/>]
                            </td>
                            <!-- total errors -->

                                    <xsl:if test="not(($cs_projects_nmb) > 0)">
                                                                                       
                                            <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                                <b>0</b>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>                                            
                                            <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                                <b>0</b>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>                                            
                                            <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                                <b>0</b>
                                                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                            </td>

                                    </xsl:if>
                                    <xsl:if test="($cs_projects_nmb) > 0">

                                            <xsl:call-template name="totErrs"/>

                                    </xsl:if>

                            <!-- checked / total files -->

                                        <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                            <b>
                                                <xsl:value-of select="($tchecked_files)"/>
                                            </b>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                        </td>
                                        <td class="singleborder right_separator" align="center" bgcolor="{$cs_bcolor}">
                                            <b>
                                                <xsl:value-of select="($ttotFiles)"/>
                                            </b>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                        </td>

                            <!-- checked / total lines -->

                                        <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                            <b>
                                                <xsl:value-of select="($tchecked_lines)"/>
                                            </b>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                        </td>
                                        <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
                                            <b>
                                                <xsl:value-of select="($ttotLns)"/>
                                            </b>
                                            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                                        </td>

                        </tr>
                    </table>
                </td>
            </tr>
        </table>
    </xsl:template>
    
    <!-- =================  print coding standards summary errors - text mode ============================ -->
    
    <xsl:template name="cs_summary_text">
        <table>                        
            <tr>
                <td>
                    <xsl:value-of select="$RES_PARAMETER_MODULE"/>                                
                </td>
                <td>Suppressed</td>                                
                <xsl:if test="($process_quick_fixes = 'true')">
                    <td>qfix</td>
                </xsl:if>
                <td>total</td>
                <td>per 10000</td>                                                           
                <td>Files checked</td>                            
                <td>Files total</td>
                <td>Lines checked</td>                                
                <td>Lines total</td>                                                                
            </tr>
            
            <xsl:variable name="total_time" select="/ResultsSession/CodingStandards/@time"/>
            <xsl:variable name="tchecked_lines" saxon:assignable="yes">0</xsl:variable>
            <xsl:variable name="ttotLns" saxon:assignable="yes">0</xsl:variable>
            <xsl:variable name="tchecked_files" saxon:assignable="yes">0</xsl:variable>
            <xsl:variable name="ttotFiles" saxon:assignable="yes">0</xsl:variable>
            <xsl:for-each select="/ResultsSession/CodingStandards/Projects/Project">
            	<xsl:sort select="@name"/>
                <xsl:variable name="project_name" select="@name"/>               
                <tr>                                
                    <td>                                    
                        <xsl:value-of select="($project_name)"/>
                    </td>
                    
                    <xsl:variable name="totErrs" select="@totErrs"/>
                    <xsl:variable name="qfixErrs" select="@qfixErrs"/>                                
                    
                    
                    <td>
                        <xsl:value-of select="@suppErrs"/>                                                
                    </td>                                            
                    <xsl:if test="($process_quick_fixes = 'true')">
                        <td>
                            <xsl:value-of select="@qfixErrs"/>
                        </td>
                    </xsl:if>
                    <td>
                        <xsl:value-of select="$totErrs"/>
                    </td>                                            
                    <xsl:variable name="checkedLns" select="@checkedLns"/>
                    <xsl:variable name="errs" saxon:assignable="yes">0</xsl:variable>
                    <xsl:if test="($checkedLns) > 0">
                        <saxon:assign name="errs" select="floor((10000 * $totErrs) div $checkedLns)"/>
                    </xsl:if>
                    <td>
                        <xsl:value-of select="$errs"/>
                    </td>                                        
                    
                    <!-- files -->
                    <xsl:variable name="cchecked_files" select="@checkedFiles"/>
                    <xsl:variable name="ctotFiles" select="@totFiles"/>
                    <saxon:assign name="tchecked_files" select="$tchecked_files + $cchecked_files"/>
                    <saxon:assign name="ttotFiles" select="$ttotFiles + $ctotFiles"/>
                    
                    <td>                                   
                        <xsl:value-of select="($cchecked_files)"/>                                   
                    </td>                                
                    <td>
                        <xsl:value-of select="($ctotFiles)"/>
                    </td>
                    
                    <xsl:variable name="cchecked_lines" select="@checkedLns"/>
                    <xsl:variable name="ctotLns" select="@totLns"/>
                    <saxon:assign name="tchecked_lines" select="$tchecked_lines + $cchecked_lines"/>
                    <saxon:assign name="ttotLns" select="$ttotLns + $ctotLns"/>
                    <td align="right">
                        <xsl:value-of select="($cchecked_lines)"/>
                    </td>                                
                    <td align="right">
                        <xsl:value-of select="($ctotLns)"/>
                    </td>
                </tr>
            </xsl:for-each>
            <tr>
                <!-- total time, problem -->
                <td>
                    <xsl:value-of select="$RES_PARAMETER_TOTAL"/> [<xsl:value-of select="($total_time)"/>]
                </td>                            
                                                    
                        <xsl:if test="not(($cs_projects_nmb) > 0)">
                            
                                <td>0</td>
                                <xsl:if test="($process_quick_fixes = 'true')">
                                    <td>0</td>                   
                                </xsl:if>
                                <td>0</td>
                                <td>0</td>
                                <td>0</td>
                            
                        </xsl:if>
                        <xsl:if test="($cs_projects_nmb) > 0">                            
                                <xsl:call-template name="totErrs_text"/>                            
                        </xsl:if>                                            
                <td>                    
                    <xsl:value-of select="($tchecked_files)"/>                                       
                </td>                
                <td>                    
                    <xsl:value-of select="($ttotFiles)"/>                    
                </td>
                                        

                <td>
                    <xsl:value-of select="($tchecked_lines)"/>                    
                </td>                
                <td>                    
                    <xsl:value-of select="($ttotLns)"/>                    
                </td>
                        
            </tr>
        </table>

    </xsl:template>
            
    <!-- =================  print qfix / total errors ============================ -->
    
    <xsl:template name="totErrs">
    <xsl:variable name="errors_suppr" saxon:assignable="yes">0</xsl:variable>
    <xsl:variable name="errors_total" saxon:assignable="yes">0</xsl:variable>
    <xsl:variable name="errors_qfix" saxon:assignable="yes">0</xsl:variable>
    <xsl:variable name="checkedLns" saxon:assignable="yes">0</xsl:variable>
    <xsl:for-each select="/ResultsSession/CodingStandards/Projects/Project">
    <saxon:assign name="errors_suppr" select="($errors_suppr) + @suppErrs"/>
    <saxon:assign name="errors_total" select="($errors_total) + @totErrs"/>
    <saxon:assign name="errors_qfix" select="($errors_qfix) + @qfixErrs"/>
    <saxon:assign name="checkedLns" select="($checkedLns) + @checkedLns"/>
    </xsl:for-each> 
    <xsl:variable name="errs" saxon:assignable="yes">0</xsl:variable>
    <xsl:if test="($checkedLns) > 0">
    <saxon:assign name="errs" select="floor((10000 * $errors_total) div $checkedLns)"/>
    </xsl:if>   

    <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>  
    <b>
    <xsl:value-of select="($errors_suppr)"/>
    </b>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    <xsl:if test="($process_quick_fixes = 'true')">
    <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>  
    <b>
    <xsl:value-of select="($errors_qfix)"/>
    </b>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    </xsl:if>
    <td class="singleborder" align="center" bgcolor="{$cs_bcolor}">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>  
    <b>
    <xsl:value-of select="($errors_total)"/>
    </b>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    <td class="singleborder right_separator" align="center" bgcolor="{$cs_bcolor}">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>  
    <b>
    <xsl:value-of select="($errs)"/>
    </b>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    </xsl:template> 
    
    <!-- =================  print qfix / total errors / text mode ============================ -->
    
    <xsl:template name="totErrs_text">
        <xsl:variable name="errors_suppr" saxon:assignable="yes">0</xsl:variable>
        <xsl:variable name="errors_total" saxon:assignable="yes">0</xsl:variable>
        <xsl:variable name="errors_qfix" saxon:assignable="yes">0</xsl:variable>
        <xsl:variable name="checkedLns" saxon:assignable="yes">0</xsl:variable>
        <xsl:for-each select="/ResultsSession/CodingStandards/Projects/Project">
            <saxon:assign name="errors_suppr" select="($errors_suppr) + @suppErrs"/>
            <saxon:assign name="errors_total" select="($errors_total) + @totErrs"/>
            <saxon:assign name="errors_qfix" select="($errors_qfix) + @qfixErrs"/>
            <saxon:assign name="checkedLns" select="($checkedLns) + @checkedLns"/>
        </xsl:for-each> 
        <xsl:variable name="errs" saxon:assignable="yes">0</xsl:variable>
        <xsl:if test="($checkedLns) > 0">
            <saxon:assign name="errs" select="floor((10000 * $errors_total) div $checkedLns)"/>
        </xsl:if>   
        
        <td>            
            <xsl:value-of select="($errors_suppr)"/>            
        </td>        
        <xsl:if test="($process_quick_fixes = 'true')">
            <td>
                
                <xsl:value-of select="($errors_qfix)"/>                
            </td>                       
        </xsl:if>
        <td>            
            <xsl:value-of select="($errors_total)"/>            
        </td>        
        <td>       
            <xsl:value-of select="($errs)"/>            
        </td>
    </xsl:template>
       
    <!-- ================= print coding standards active rules ============================ -->
    
    <xsl:template name="cs_active_rules">
    <table width='{$width}' border='0' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>     
    <tr>
    <td>
    <table width='100%' border='0' cellpadding='0' cellspacing='0'>
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <tr>
    <td>
    <table width="100%" border="0" cellpadding="0" cellspacing="0">
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>
    <tr>
    <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">          
       <td width="25%"></td>
    </xsl:if>
    <td align="center">
       <div class="small_header"><xsl:value-of select="$RES_PARAMETER_ACTIVE_RULES"/></div>
    </td>
    <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">          
       <td align="right" width="25%">
          <xsl:call-template name="back_to_top"/>
       </td>
    </xsl:if>
    </tr>
    </table>
    </td>
    </tr>
    <tr><td>
        <xsl:call-template name="print_header_separator"/>
    </td></tr>
    <tr><td align="left">
    <table width='100%' cellpadding='0' cellspacing='0' class="doubleborder">
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>      
        <tr><td>
        
    <saxon:assign name="isFirstRow">true</saxon:assign>
    <xsl:for-each select="/ResultsSession/CodingStandards/Rules/CategoriesList/Category">
    <xsl:call-template name="cs_category">
    <xsl:with-param name="depth" select="0"/>
    </xsl:call-template>
    </xsl:for-each>
    </td></tr>
    </table>
    </td></tr>
    </table>
    </td>
    </tr>
    </table>
    </xsl:template>

    <!-- ================= print subtree of a single coding standards category ============================ -->
    
    <xsl:template name="cs_category">
    <xsl:param name="depth"/>

    <xsl:variable name="cat" select="@name"/>
    <xsl:variable name="rulesCount" saxon:assignable="yes" select="count(/ResultsSession/CodingStandards/Rules/RulesList/Rule[@cat=($cat)])"/>
    
    <xsl:for-each select=".//Category">
        <xsl:variable name="subCat" select="./@name"/>
        <saxon:assign name="rulesCount" select="$rulesCount + count(/ResultsSession/CodingStandards/Rules/RulesList/Rule[@cat=($subCat)])"/>
    </xsl:for-each>
    
    <xsl:variable name="rowStyle" saxon:assignable="yes">tree</xsl:variable>
    <!--xsl:if test="$isFirstRow = 'true'">
          <saxon:assign name="rowStyle">root</saxon:assign>
          <saxon:assign name="isFirstRow" select="false"/>
    </xsl:if-->
    
    <table cellspacing="0" cellpadding="0">
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>
    <tr><td class="{$rowStyle}">
    <xsl:call-template name="make_indentation">
       <xsl:with-param name="indentation" select="$depth * 4"/>
    </xsl:call-template>
    
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><b>[<xsl:value-of select="$rulesCount"/>/<xsl:value-of select="@rules"/>]
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="@desc"/></b>       
    <xsl:call-template name="standards_rule_link_in_tree">
       <xsl:with-param name="id" select="$cat"/>
       <xsl:with-param name="sev"></xsl:with-param>
    </xsl:call-template>
    </td></tr></table>
    
    <xsl:for-each select="./Category">
       <xsl:call-template name="cs_category">
          <xsl:with-param name="depth" select="$depth + 1"/>
       </xsl:call-template>
    </xsl:for-each>
    
    <xsl:for-each select="/ResultsSession/CodingStandards/Rules/RulesList/Rule[@cat=($cat)]">
       <xsl:call-template name="cs_category_rule">
          <xsl:with-param name="depth" select="$depth + 1"/>
       </xsl:call-template>
    </xsl:for-each>
    
    </xsl:template>

    <!-- ================= print data a single coding standards rule ============================ -->
    
    <xsl:template name="cs_category_rule">
       <xsl:param name="depth"/>

       <table cellspacing="0" cellpadding="0">
       <xsl:if test="($report_format_mode='pdf')">
          <xsl:attribute name="cols">100%</xsl:attribute>
       </xsl:if>
       <tr><td class="tree">
       <xsl:call-template name="make_indentation">
          <xsl:with-param name="indentation" select="$depth * 4"/>
       </xsl:call-template>
       <xsl:value-of select="@desc"/>
       <xsl:call-template name="standards_rule_link_in_tree">
          <xsl:with-param name="id" select="@id"/>
          <xsl:with-param name="sev" select="@sev"/>
       </xsl:call-template>
       </td></tr></table>
       
    </xsl:template>
    
    <!-- =================  print coding standards summary errors ============================ -->
    
    <xsl:template name="cs_error_summary">
    
    <table width='{$width}' cellpadding='0' cellspacing='0'>
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>     
    <tr>
    <td>
    
    <table width='100%' cellpadding='0' cellspacing='0'>
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>     

    <xsl:variable name="catSevDisplayMode" saxon:assignable="yes">switch</xsl:variable>
    <xsl:variable name="sevDisplayStyle" saxon:assignable="yes">display:none;</xsl:variable>
    <xsl:if test="(($report_type) = ($email_report)) or ($report_format_mode = 'pdf')">
        <saxon:assign name="catSevDisplayMode">sequential</saxon:assign>
        <saxon:assign name="sevDisplayStyle">display:block;</saxon:assign>
    </xsl:if>

    <xsl:if test="($catSevDisplayMode = 'switch')">
        <xsl:call-template name="cs_summary_title">
          <xsl:with-param name="display_mode">switch</xsl:with-param>
        </xsl:call-template>
    </xsl:if>
    <xsl:if test="($catSevDisplayMode = 'sequential')">
        <xsl:call-template name="cs_summary_title">
          <xsl:with-param name="display_mode">cat</xsl:with-param>
        </xsl:call-template>
    </xsl:if>

    <tr><td align="left">
    <div id="cs_cat" style="display:block;">
    <table width='100%' class="doubleborder" cellpadding='0' cellspacing='0'>
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">100%</xsl:attribute>
    </xsl:if>      

    <xsl:variable name="catList" select="/ResultsSession/CodingStandards/Rules/CategoriesList//Category"/>
    <saxon:assign name="isFirstRow">true</saxon:assign>

    <xsl:for-each select="$catList">
    <xsl:call-template name="cstandard">
    <xsl:with-param name="cat" select="@name"/>
    <xsl:with-param name="desc" select="@desc"/>
    <xsl:with-param name="authidx">0</xsl:with-param>
    </xsl:call-template>
    </xsl:for-each>
    </table>
    </div>
    </td></tr>
    <xsl:if test="($catSevDisplayMode = 'sequential')">
        <xsl:call-template name="cs_summary_title">
          <xsl:with-param name="display_mode">sev</xsl:with-param>
        </xsl:call-template>
    </xsl:if>
    <tr><td align="left">

    <div id="cs_sev" style="{$sevDisplayStyle}">
    <table width='100%' class="doubleborder" cellpadding='0' cellspacing='0'>   
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
        </xsl:if>   
    <saxon:assign name="isFirstRow">true</saxon:assign>
    <xsl:call-template name="cstandard_sev">
    <xsl:with-param name="sev">1</xsl:with-param>
    <xsl:with-param name="sevlabel"><xsl:value-of select="$RES_PARAMETER_SEVERITY_1"/></xsl:with-param>
    <xsl:with-param name="authidx">0</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="cstandard_sev">
    <xsl:with-param name="sev">2</xsl:with-param>
    <xsl:with-param name="sevlabel"><xsl:value-of select="$RES_PARAMETER_SEVERITY_2"/></xsl:with-param>
    <xsl:with-param name="authidx">0</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="cstandard_sev">
    <xsl:with-param name="sev">3</xsl:with-param>
    <xsl:with-param name="sevlabel"><xsl:value-of select="$RES_PARAMETER_SEVERITY_3"/></xsl:with-param>
    <xsl:with-param name="authidx">0</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="cstandard_sev">
    <xsl:with-param name="sev">4</xsl:with-param>
    <xsl:with-param name="sevlabel"><xsl:value-of select="$RES_PARAMETER_SEVERITY_4"/></xsl:with-param>
    <xsl:with-param name="authidx">0</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="cstandard_sev">
    <xsl:with-param name="sev">5</xsl:with-param>
    <xsl:with-param name="sevlabel"><xsl:value-of select="$RES_PARAMETER_SEVERITY_5"/></xsl:with-param>
    <xsl:with-param name="authidx">0</xsl:with-param>
    </xsl:call-template>
    </table>
    </div>
    </td></tr>
    </table>
    </td>
    </tr>
    </table>
    </xsl:template> 

    <!-- =================  print coding standard details sorted by cat ============================ -->
    
    <xsl:template name="cstandard">
    <xsl:param name="cat"/>
    <xsl:param name="desc"/>
    <xsl:param name="auth"/>
    <xsl:param name="authidx"/>
    <xsl:param name="urgent"/>

    <xsl:variable name="total" saxon:assignable="yes">0</xsl:variable>
    
    <xsl:if test="$authidx > 0">
       <xsl:if test="not(($urgent) = 'true')">
          <saxon:assign name="total" select="results:getTotalValue(./@authTot,$authidx)"/>
       </xsl:if>    
       <xsl:if test="($urgent) = 'true'">
          <saxon:assign name="total" select="results:getTotalValue(./@authUrg,$authidx)"/>
       </xsl:if>
    </xsl:if>    
    <xsl:if test="$authidx = 0">
        <saxon:assign name="total" select="./@total"/>
    </xsl:if>

    <xsl:if test="($total) &gt; 0">
    
    <xsl:variable name="rowStyle" saxon:assignable="yes">tree</xsl:variable>
    <!--xsl:if test="$isFirstRow = 'true'">
          <saxon:assign name="rowStyle">root</saxon:assign>
          <saxon:assign name="isFirstRow" select="false"/>
    </xsl:if-->
    
    <tr>
       <td class="{$rowStyle}">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    [<b><xsl:value-of select="($total)"/></b>]
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <b><xsl:value-of select="($desc)"/></b>
    <xsl:call-template name="standards_rule_link_in_tree">
       <xsl:with-param name="id" select="$cat"/>
       <xsl:with-param name="sev"></xsl:with-param>       
    </xsl:call-template>    
    </td>
    </tr>
    <xsl:variable name="rulesList" select="/ResultsSession/CodingStandards/Rules/RulesList/Rule[@cat=($cat)]"/>
    <xsl:for-each select="$rulesList">
    <xsl:call-template name="cstandard_rule">
    <xsl:with-param name="cat" select="($cat)"/>
    <xsl:with-param name="id" select="@id"/>
    <xsl:with-param name="sev" select="@sev"/>
    <xsl:with-param name="desc" select="@desc"/>
    <xsl:with-param name="auth" select="($auth)"/>
    <xsl:with-param name="authidx" select="($authidx)"/>
    <xsl:with-param name="qfix" select="@qfix"/>
    <xsl:with-param name="urgent" select="($urgent)"/>
    </xsl:call-template>
    </xsl:for-each> 
    
    </xsl:if>    
    </xsl:template>
    
    <!-- =================  print coding standard details sorted by severity ============================ -->
    
    <xsl:template name="cstandard_sev">
    <xsl:param name="sev"/>
    <xsl:param name="sevlabel"/>
    <xsl:param name="auth"/>
    <xsl:param name="authidx"/>
    <xsl:param name="urgent"/>
    
    <xsl:variable name="total" saxon:assignable="yes">0</xsl:variable>
    <xsl:variable name="severityStats" saxon:assignable="yes" select="/ResultsSession/CodingStandards/Rules/SeverityList/Severity[@id=($sev)]"/>
    
    <xsl:if test="$authidx > 0">    
       <xsl:if test="not(($urgent) = 'true')">
          <saxon:assign name="total" select="results:getTotalValue($severityStats/@authTot,$authidx)"/>
       </xsl:if>    
       <xsl:if test="($urgent) = 'true'">
          <saxon:assign name="total" select="results:getTotalValue($severityStats/@authUrg,$authidx)"/>
       </xsl:if>
    </xsl:if>    
    <xsl:if test="$authidx = 0">
       <saxon:assign name="total" select="$severityStats/@total"/>
    </xsl:if>
        
    <xsl:if test="($total) &gt; 0">

    <xsl:variable name="rowStyle" saxon:assignable="yes">tree</xsl:variable>
    <!--xsl:if test="$isFirstRow = 'true'">
          <saxon:assign name="rowStyle">root</saxon:assign>
          <saxon:assign name="isFirstRow" select="false"/>
    </xsl:if-->
    
    <tr>
       <td class="{$rowStyle}">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    [<b><xsl:value-of select="($total)"/></b>]
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>        
        <b>
        	<xsl:value-of select="$RES_PARAMETER_SEVERITY"/> 
		    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        	<xsl:value-of select="($sev)"/> - <xsl:value-of select="($sevlabel)"/>       	
       	</b>
    </td>
    </tr>

    <xsl:variable name="rulesList" select="/ResultsSession/CodingStandards/Rules/RulesList/Rule[@sev=($sev)]"/>
    <xsl:for-each select="$rulesList">
    <xsl:call-template name="cstandard_rule">
    <xsl:with-param name="cat" select="@cat"/>
    <xsl:with-param name="id" select="@id"/>
    <xsl:with-param name="sev" select="($sev)"/>
    <xsl:with-param name="desc" select="@desc"/>
    <xsl:with-param name="auth" select="($auth)"/>
    <xsl:with-param name="authidx" select="($authidx)"/>
    <xsl:with-param name="qfix" select="@qfix"/>
    <xsl:with-param name="urgent" select="($urgent)"/>

    </xsl:call-template>
    </xsl:for-each>
    
    </xsl:if>
    </xsl:template> 

    <!-- =================  print coding standard rule details ============================ -->
    
    <xsl:template name="cstandard_rule">
    <xsl:param name="cat"/>
    <xsl:param name="id"/>
    <xsl:param name="sev"/>
    <xsl:param name="desc"/>
    <xsl:param name="auth"/>
    <xsl:param name="authidx"/>
    <xsl:param name="qfix"/>
    <xsl:param name="urgent"/>

    <xsl:variable name="total" saxon:assignable="yes">0</xsl:variable>
        
    <xsl:if test="$authidx > 0">
       <xsl:if test="not(($urgent) = 'true')">
          <saxon:assign name="total" select="results:getTotalValue(./@authTot,$authidx)"/>         
       </xsl:if>    
       <xsl:if test="($urgent) = 'true'">
          <saxon:assign name="total" select="results:getTotalValue(./@authUrg,$authidx)"/>
       </xsl:if>
    </xsl:if>    
    <xsl:if test="$authidx = 0">
       <saxon:assign name="total" select="./@total"/>
    </xsl:if>
        
    <xsl:if test="($total) &gt; 0">
    <tr>
    <td class="tree_node">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    
    [<b><xsl:value-of select="($total)"/></b>]
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    <xsl:value-of select="($desc)"/>
    <xsl:call-template name="standards_rule_link_in_tree">
       <xsl:with-param name="id" select="($id)"/>
       <xsl:with-param name="sev" select="($sev)"/>
    </xsl:call-template>
    <xsl:if test="($process_quick_fixes = 'true') and (string-length($qfix) > 0)">
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
        <font class="orange"><xsl:value-of select="$RES_PARAMETER_QFIX"/></font>
    <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </xsl:if>
    </td>
    </tr>
    </xsl:if>
    </xsl:template> 
    
    <!-- ================= print BugDetective error path ============================ -->
    <xsl:template name="bd_dump_ElDescList">
        <xsl:param name="descriptors"/>
        <xsl:param name="extraSpace"/>
        <xsl:param name="isMainMethod"/>
        
        <xsl:for-each select="$descriptors">
            <xsl:variable name="fontColor" saxon:assignable="yes"/>
            <saxon:assign name="fontColor">
                <xsl:text>gray</xsl:text>
            </saxon:assign>             
            <xsl:if test="not( ($isMainMethod = 'true') and (position() = 1) )">
            	<xsl:text>&#xa;</xsl:text>
            </xsl:if>
            <!-- Cause / Point -->
            <xsl:value-of select="$extraSpace"/>
            <xsl:variable name="space" saxon:assignable="yes"/>
            <saxon:assign name="space">
                <xsl:value-of select="$extraSpace"/>
                <xsl:text>&#160;</xsl:text>
                <xsl:text>&#160;</xsl:text>
                <xsl:text>&#160;</xsl:text>
                <xsl:text>&#160;</xsl:text>
                <xsl:text>&#160;</xsl:text>
                <xsl:text>&#160;</xsl:text>
                <xsl:text>&#160;</xsl:text>
                <xsl:text>&#160;</xsl:text>                
            </saxon:assign>
            <xsl:for-each select="Anns/Ann">
                <xsl:if test="(@kind = 'cause')">
                    <saxon:assign name="fontColor">
                        <xsl:value-of select="$FA_cause_message_color"/>
                    </saxon:assign>
                    <font color="{$fontColor}">
                        <b><xsl:value-of select="@msg"/></b>
                        <xsl:text>&#xa;</xsl:text>
                        <xsl:value-of select="$extraSpace"/>
                    </font>
                </xsl:if>
                <xsl:if test="(@kind = 'point')">
                    <saxon:assign name="fontColor">
                        <xsl:value-of select="$FA_point_message_color"/>
                    </saxon:assign>
                    <font color="{$fontColor}">
                        <b><xsl:value-of select="@msg"/></b>
                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                        <xsl:text>&#xa;</xsl:text>
                        <xsl:value-of select="$extraSpace"/>
                    </font>
                </xsl:if>
            </xsl:for-each>
            
            <!-- JAVA ? -->
            <font color="{$fontColor}">
            <xsl:if test="string-length(@ln ) > 0">
            	<xsl:value-of select="textutil:getLastPathSegment(@srcRngFile)"/>                
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:text>(</xsl:text><xsl:value-of select="@ln"/><xsl:text>):</xsl:text>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </xsl:if>
			</font>
            
            <!-- code -->
            <xsl:choose>			
                <xsl:when test="(@ElType = '.')">
                    <font color="gray">
                        <xsl:value-of select="@desc"/>
                    </font>
                </xsl:when>
                <xsl:otherwise>
                     <font color="black">
                        <xsl:value-of select="@desc"/>
                    </font>
                </xsl:otherwise>
	        </xsl:choose>
            <xsl:for-each select="Anns/Ann">
                <font color="{$FA_comment_message_color}">
                    <xsl:if test="(@kind != 'cause' and @kind !='point')">
                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                        <xsl:text>***</xsl:text>
                        <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                        <xsl:value-of select="@msg"/>
                    </xsl:if>
                </font>
            </xsl:for-each>
            <!-- entering to method -->
            <xsl:call-template name="bd_dump_ElDescList">
                <xsl:with-param name="descriptors" select="ElDescList/ElDesc"/>
                <xsl:with-param name="extraSpace" select="$space"/>
                <xsl:with-param name="isMainMethod">false</xsl:with-param>
            </xsl:call-template>
        </xsl:for-each>
    </xsl:template>
    
    <xsl:template name="bd_dump_path">
        <xsl:param name="checkedFilesStyle"/>
        <xsl:param name="violationID"/>
        
        <xsl:variable name="html" saxon:assignable="yes"></xsl:variable>
        <saxon:assign name="html">
            <xsl:call-template name="bd_dump_ElDescList">
                <xsl:with-param name="descriptors" select="./ElDescList/ElDesc"/>
                <xsl:with-param name="extraSpace"></xsl:with-param>
                <xsl:with-param name="isMainMethod">true</xsl:with-param>
            </xsl:call-template>
        </saxon:assign>
        <xsl:if test="string-length($html) > 0">
          <xsl:variable name="violStyle" saxon:assignable="yes"/>
          <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">
              <saxon:assign name="violStyle">
                  <xsl:text>display:none</xsl:text>
              </saxon:assign>
          </xsl:if>
          <xsl:variable name="bgColor" saxon:assignable="yes"/>
          <xsl:choose>
              <xsl:when test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">
                <saxon:assign name="bgColor">
                      <xsl:text>#F5F5F5</xsl:text>
                  </saxon:assign>
              </xsl:when>
              <xsl:otherwise>
                  <saxon:assign name="bgColor">
                      <xsl:text>#FFFFFF</xsl:text>
                  </saxon:assign>
              </xsl:otherwise>
          </xsl:choose>
          <xsl:if test="($checkedFilesStyle = 'true')">
            <tr id="{$violationID}" style="{$violStyle}"> 
              <td style="padding-left:10px" class="tree"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td><xsl:comment>bd_legend_required_marker</xsl:comment>
              <td bgcolor="{$bgColor}"></td>
              <td bgcolor="{$bgColor}"></td>
              <td bgcolor="{$bgColor}" colspan="3">
              <table width="100%" style="table-layout:fixed">
                <xsl:if test="($report_format_mode='pdf')">
                    <xsl:attribute name="cols">100%</xsl:attribute>
                </xsl:if>
                <tr><td>              
                  <pre class="tree" wrap="wrap">
                    <xsl:call-template name="bd_dump_ElDescList">
                        <xsl:with-param name="descriptors" select="./ElDescList/ElDesc"/>
                        <xsl:with-param name="extraSpace"></xsl:with-param>
                        <xsl:with-param name="isMainMethod">true</xsl:with-param>
                    </xsl:call-template>
                  </pre>
                 </td></tr>
              </table>
              </td>
           </tr>
           <saxon:assign name="globalIndex" select="$globalIndex+ 1"/>   
           </xsl:if>
           <xsl:if test="not($checkedFilesStyle = 'true')">
           <tr id="{$violationID}" style="{$violStyle}">
              <td bgcolor="{$bgColor}" style="padding-left:10px" class="tree"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td><xsl:comment>bd_legend_required_marker</xsl:comment>
              <td bgcolor="{$bgColor}"></td>
              <td bgcolor="{$bgColor}" style="padding-right:10px;" colspan="2">
              <table width="100%" style="table-layout:fixed">
                <xsl:if test="($report_format_mode='pdf')">
                    <xsl:attribute name="cols">100%</xsl:attribute>
                </xsl:if>
                <tr><td>
                  <pre class="tree" wrap="wrap">
                    <xsl:call-template name="bd_dump_ElDescList">
                        <xsl:with-param name="descriptors" select="./ElDescList/ElDesc"/>
                        <xsl:with-param name="extraSpace"></xsl:with-param>
                        <xsl:with-param name="isMainMethod">true</xsl:with-param>
                    </xsl:call-template>
                  </pre>
                 </td></tr>
              </table>
              </td>
           </tr>   
           <saxon:assign name="globalIndex" select="$globalIndex+ 1"/>
           </xsl:if>
        </xsl:if>
    </xsl:template> 
        
    <!-- ================= print BugDetective legend ============================ -->
    
    <xsl:template name='bd_draw_developer_legend'>
       <xsl:param name='auth'/>  
       <xsl:param name='param_urgent'/>

       <xsl:variable name="author_fa_errors" select="tmp" saxon:assignable="yes"/>
       <xsl:if test="not(($param_urgent) = 'true')">
          <saxon:assign name="author_fa_errors" select="count(/ResultsSession/CodingStandards/StdViols/FlowViol[@auth=($auth) and not(@supp='true')])"/>
       </xsl:if>
       <xsl:if test="($param_urgent) = 'true'">
          <saxon:assign name="author_fa_errors" select="count(/ResultsSession/CodingStandards/StdViols/FlowViol[@auth=($auth) and not(@supp='true') and @urgent='true'])"/>
       </xsl:if>
        <xsl:if test="($author_fa_errors > 0)">
            <xsl:call-template name="bd_draw_legend"/>
            <br/>
        </xsl:if>
    </xsl:template>

    <xsl:template name="bd_draw_manager_legend">

        <xsl:variable name="viols_counter" select="count(/ResultsSession/CodingStandards/StdViols/FlowViol)"/>        
        <xsl:if test="($viols_counter > 0)">
            <xsl:call-template name="bd_draw_legend"/>
        </xsl:if>

    </xsl:template>

    <xsl:template name="bd_draw_legend">

            <table width='800' style="padding-left:4px" cellpadding='0' cellspacing='0'>
                <xsl:if test="($report_format_mode='pdf')">
                    <xsl:attribute name="cols">33% 33% 33%</xsl:attribute>
                </xsl:if>     
                <tr><td colspan="3"><b><xsl:value-of select="$RES_PARAMETER_BUG_DETECTIVE_LEGEND"/><br/><br/></b></td></tr>                
                <tr>
                   <td>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <font color="{$FA_cause_message_color}"><b><xsl:value-of select="$RES_PARAMETER_MESSAGE"/></b></font> - <xsl:value-of select="$RES_PARAMETER_VIOLATION_CAUSE"/>
					 </td>
				   <td>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <font color="{$FA_point_message_color}"><b><xsl:value-of select="$RES_PARAMETER_MESSAGE"/></b></font> - <xsl:value-of select="$RES_PARAMETER_VIOLATION_POINT"/>
					 </td> 
				   <td>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                      <font color="{$FA_comment_message_color}"><b><xsl:value-of select="$RES_PARAMETER_MESSAGE"/></b></font> - <xsl:value-of select="$RES_PARAMETER_PATH_ELEMENT_ANNOTATION"/>
				   </td>
                </tr>
                <xsl:comment>bd_legend_present_marker</xsl:comment>
            </table>      

    </xsl:template>
    
    <!-- =================  supp_messages ============================ -->
    
    <xsl:template name="supp_messages">
    <xsl:param name="auth"/>
    <xsl:param name="authid"/>
    <xsl:variable name="tmp_src_name" select="empty" saxon:assignable="yes"/>
    
    <xsl:variable name="supp_msgs" saxon:assignable="yes">0</xsl:variable>
    <xsl:for-each select="/ResultsSession/CodingStandards/Supps/Supp[@suppAuth=($auth)]">
        <xsl:variable name="ref_id" select="@refId"/>
        <xsl:variable name="single_suppr_msgs"
            select="count(/ResultsSession/CodingStandards/StdViols/*[@suppRef=($ref_id) and @supp='true'])"/>
        <saxon:assign name="supp_msgs" select="$supp_msgs + $single_suppr_msgs"/>
    </xsl:for-each>

    <table width="{$width}" cellpadding="0" cellspacing="0" >
        <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">25% 25% 25% 25%</xsl:attribute>
        </xsl:if>
    <tr>
        <xsl:call-template name="details_table_auth_header">
    		<xsl:with-param name="auth" select="$auth"/>
    		<xsl:with-param name="anchor" select="concat('css_',$auth)"/>
    		<xsl:with-param name="number" select="$supp_msgs"/>    		
			<xsl:with-param name="message" select="$RES_PARAMETER_SUPPRESSIONS"/>
			<xsl:with-param name="colspan" select="3"/>
   	  	</xsl:call-template>
    </tr>
    <tr><td colspan="4">
       <xsl:call-template name="print_header_separator"/>
    </td></tr>
    
    <tr>
    <td colspan="4" align="left">
    <xsl:if test="($supp_msgs) > 0">
    <table width="100%" bgcolor="#FFFFFF" class="doubleborder" cellpadding="0" cellspacing="0">
    <xsl:if test="($report_format_mode='pdf')">
        <xsl:attribute name="cols">1% 5% 45% 35% 14%</xsl:attribute>
    </xsl:if>
   	
    <xsl:for-each select="/ResultsSession/CodingStandards/Supps/Supp[@suppAuth=($auth)]">
    <xsl:sort select="@suppLoc"/>

    <!--xsl:variable name="smsg" select="@suppMsg"/>    
    <xsl:variable name="id" select="substring-before($smsg,':')"/>
    <xsl:variable name="msg" select="substring-after($smsg,':')"/-->
    <xsl:variable name="line" select="@suppLine"/>
    <xsl:variable name="id" select="@suppRule"/>
    <xsl:variable name="msg" select="@suppMsg"/>
    <xsl:variable name="reason" select="@suppRsn"/>
    <xsl:variable name="src_name" select="@suppLoc"/>
    
    <xsl:variable name="ref_id" select="@refId"/>
    <xsl:for-each select="/ResultsSession/CodingStandards/StdViols/*[@suppRef=($ref_id) and @supp='true']">
    
    <xsl:if test="not($tmp_src_name = $src_name)">      
    <tr>    
    <td style="padding-left:10px;padding-right:10px" colspan="5" class="tree"><b>
    <xsl:value-of select="($src_name)"/></b>
    </td>
    </tr>    
    </xsl:if>
    
    <tr>
    <td width="1%" class="tree"></td>
    <td width="2%" class="tree" align="right">
    <font class="gray"><xsl:value-of select="($line)"/>:</font><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
    </td>
    <td class="tree">
    <xsl:value-of select="($msg)"/>
    </td>
    <td class="tree">
    <xsl:value-of select="($reason)"/>
    </td>
    <td style="padding-right:10px" align="right" class="tree">
    <font class="gray"><xsl:value-of select="($id)"/></font>
    </td>
    </tr>
    
    <saxon:assign name="tmp_src_name" select="$src_name"/>

    </xsl:for-each>
    </xsl:for-each> 
    </table>
    </xsl:if>
    </td>
    </tr>       
    <tr>
    <td colspan="3"><br/></td>
    </tr>
    </table>
    </xsl:template>    
    
    <!-- =================  print standards tested files details (1)  ============================ -->
    
    <xsl:template name="standards_tested_files_details">
        <xsl:if test="($static_details) > 0">
            <table width='{$width}' cellpadding='0' cellspacing='0'>
            
                <xsl:if test="($report_format_mode='pdf')">
                    <xsl:attribute name="cols">100%</xsl:attribute>
                </xsl:if>               
                <tr>
                    <td>
                        <xsl:call-template name="standards_tested_files_summary"/>
                    </td>
                </tr>
            </table>
        </xsl:if>
    </xsl:template>    
    
    <!-- =================  print standards tested files summary (2) ============================ -->
    
    <xsl:template name="standards_tested_files_summary">
    
       <xsl:variable name="expand_cs_details" select="'javascript:expandCSDetails()'"/>   
       <xsl:variable name="collapse_cs_details" select="'javascript:collapseCSDetails()'"/>   
    
       <table width='100%' cellpadding='0' cellspacing='0'>
          <xsl:if test="($report_format_mode='pdf')">
            <xsl:attribute name="cols">100%</xsl:attribute>
          </xsl:if>               
       <tr><td>
         <table width="100%" cellpadding="0" cellspacing="0">
             <xsl:if test="($report_format_mode='pdf')">
               <xsl:attribute name="cols">100%</xsl:attribute>
             </xsl:if>               
          <tr>
          <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">          
            <td width="40%"></td>
          </xsl:if>
          <td width="20%" align='center'>
            <div class="small_header"><xsl:value-of select="$RES_PARAMETER_STANDARDS_TESTED_FILES_DETAILS"/></div>

          </td>
          <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">      
          <td align="right" width="40%">
             <xsl:call-template name="standard_link_ref">
                <xsl:with-param name="href" select="$expand_cs_details"/>
                <xsl:with-param name="label"><xsl:value-of select="$RES_PARAMETER_EXPAND_ALL"/></xsl:with-param>
                <xsl:with-param name="class">gray_link</xsl:with-param>
                <xsl:with-param name="id" select="expand_cs_details"/>
                <xsl:with-param name="email_class">red2</xsl:with-param>
             </xsl:call-template>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:call-template name="standard_link_ref">
                <xsl:with-param name="href" select="$collapse_cs_details"/>
                <xsl:with-param name="label"><xsl:value-of select="$RES_PARAMETER_COLLAPSE_ALL"/></xsl:with-param>
                <xsl:with-param name="class">gray_link</xsl:with-param>
                <xsl:with-param name="id" select="collapse_cs_details"/>
                <xsl:with-param name="email_class">red2</xsl:with-param>
             </xsl:call-template>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
             <xsl:call-template name="back_to_top"/>
          </td>
          </xsl:if> 
          </tr>
        </table>
       </td></tr>
       <tr><td>
            <xsl:call-template name="print_header_separator"/>
       </td></tr>
       <tr><td>
       <table width="100%" class="doubleborder" cellpadding="0" cellspacing="0">
       <xsl:if test="($report_format_mode='pdf')">
           <xsl:attribute name="cols">100%</xsl:attribute>
       </xsl:if>    
       <tr><td align="left">
          <xsl:if test="($static_details) > 0">
          <saxon:assign name="globalIndex" select="0"/>
          <saxon:assign name="isFirstRow">true</saxon:assign>
          
          <ul class="root" id="cs_foldinglist">
            <xsl:for-each select="/ResultsSession/CodingStandards/TestedFilesDetails/*">
                <xsl:call-template name="standards_tested_files_tree">
                    <xsl:with-param name="depth">0</xsl:with-param>
                    <xsl:with-param name="canBreakHere" select="false"/>
                </xsl:call-template>
            </xsl:for-each>
          </ul>
          </xsl:if>
          <xsl:if test="not(($static_details) > 0)">
            <xsl:value-of select="$RES_PARAMETER_NOT_AVAILABLE"/>
          </xsl:if>
       </td></tr>
       </table>
       </td></tr>
       </table>
    </xsl:template>
    
    <!-- =================  display standards tree nodes (3) ============================ -->
    
    <xsl:template name="standards_tested_files_tree">
        <xsl:param name="depth"/>
        <xsl:param name="canBreakHere"/>
        
        <xsl:variable name="showViolations" select="boolean($report.developer_errors = 'true' and ((@total) > 0) and string-length(@loc) > 0)"/>
        <xsl:variable name="showSuppressions" select="boolean($report.suppressed_msgs = 'true' and (@supp > 0) and string-length(@loc) > 0)"/>
        <xsl:variable name="isExpandable" select="boolean(not($report_type = $email_report) and ( (count(./*) > 0) or $showViolations = 'true' or $showSuppressions = 'true') )"/>
       	<xsl:if test="($report_format_mode='pdf')">
       		<xsl:if test="$canBreakHere">		
			<xsl:if test="$globalIndex &gt; $breakingSize * 2">
				<BREAK-TABLE />
				<saxon:assign name="globalIndex" select="0" />
			</xsl:if>
			</xsl:if>		
       	</xsl:if> 
        <xsl:call-template name="standards_details_tree_node">
            <xsl:with-param name="name" select="@name"/>
            <xsl:with-param name="supp" select="@supp"/>
	    <xsl:with-param name="total" select="@total"/>
	    <xsl:with-param name="depth" select="$depth"/>
            <xsl:with-param name="expandable" select="$isExpandable"/>
        </xsl:call-template>
        <ul id="cs_foldinglist">            
        <xsl:if test="($depth > 1) and not($report_type = $email_report)">
           <xsl:attribute name="style">display:none</xsl:attribute>
        </xsl:if>
        <xsl:if test="$showViolations = 'true' or $showSuppressions = 'true'">
           <li id="item">
            <table width="89%" class="details" cellspacing="0">
            <xsl:if test="($report_format_mode='pdf')">
                <xsl:attribute name="cols">1% 4% 5% 50% 20% 20%</xsl:attribute>
            </xsl:if>
                         
           <xsl:if test="$showViolations = 'true'">
              <xsl:call-template name="standards_details_static_violations">
                 <xsl:with-param name="location" select="@loc"/>
                 <xsl:with-param name="locType" select="@locType"/>
                 <xsl:with-param name="tasksCount" select="@total"/>                
              </xsl:call-template>
           </xsl:if>
           <xsl:if test="$showSuppressions = 'true'">
              <xsl:call-template name="standards_details_supp_messages">
                 <xsl:with-param name="location" select="@loc"/>
              </xsl:call-template>
           </xsl:if>        
           </table>
           </li>
        </xsl:if>
        <xsl:variable name="childCounter" select="0" saxon:assignable="yes"/>
        <xsl:for-each select="./*">
           <xsl:sort select="@name"/>
           <saxon:assign name="childCounter" select="$childCounter + 1"/>
           <xsl:call-template name="standards_tested_files_tree">
              <xsl:with-param name="depth" select="$depth + 1"/>
              <xsl:with-param name="canBreakHere" select="($childCounter > 1)"/>
           </xsl:call-template>
        </xsl:for-each>
        </ul>		
    </xsl:template>

    <!-- =================  print standards details tree node (4) ============================ -->
    
    <xsl:template name="standards_details_tree_node">
        <xsl:param name="name"/>
        <xsl:param name="supp"/>
	<xsl:param name="total"/>
	<xsl:param name="depth"/>
        <xsl:param name="expandable"/>

        <xsl:variable name="li_id" saxon:assignable="yes">cs_foldheader</xsl:variable>
        <xsl:if test="not($expandable)">
            <saxon:assign name="li_id">item</saxon:assign>
        </xsl:if>

        <xsl:variable name="rowStyle" saxon:assignable="yes">tree</xsl:variable>
        <!--xsl:if test="$isFirstRow = 'true'">
           <saxon:assign name="rowStyle">root</saxon:assign>
           <saxon:assign name="isFirstRow" select="false"/>
        </xsl:if-->

        <xsl:variable name="font_style" saxon:assignable="yes" select="'black'"/>
        <!--  xsl:if test="($total > 0)">
            <saxon:assign name="font_style" select ="'red'"/>
        </xsl:if -->
        
        <li id="{$li_id}" class="{$rowStyle}">
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            <xsl:if test="$expandable = 'true'">
                <font class="gray">+</font>
            </xsl:if>
            <xsl:if test="not($expandable = 'true')">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </xsl:if>
            <b>
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
			<xsl:value-of select="$total"/>
			(<xsl:value-of select="($supp)"/>)            	                
            <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </b>
            <b><xsl:value-of select="($name)"/></b>	
            <saxon:assign name="globalIndex" select="$globalIndex+ 1"/>
       </li>    

    </xsl:template>
    
    <!-- =================  print static violations for tested files details (5) ============================ -->
    
    <xsl:template name="standards_details_static_violations">
        <xsl:param name="location"/>
        <xsl:param name="locType"/>
        <xsl:param name="tasksCount"/>
        
       <xsl:if test="($report.developer_errors='true') and ($report.suppressed_msgs='true')">
          <tr>
			  <td colspan="3"><b><xsl:value-of select="$RES_PARAMETER_FINDINGS"/></b>:<xsl:value-of select="($nbsp)"
			   disable-output-escaping="yes"/><xsl:value-of select="($tasksCount)"/></td>  
              <td align="right" colspan="2" nowrap="nowrap"></td>
		  </tr>
       </xsl:if>           

        <xsl:variable name="violationsList" saxon:assignable="yes"/>
        <xsl:if test="$locType = 'sym'">
            <saxon:assign name="violationsList" select="/ResultsSession/CodingStandards/StdViols/*[not(@supp='true') and (@locType=$locType) and (@resFile=$location)]"/>
        </xsl:if>
        <xsl:if test="$locType = 'sr'">
            <saxon:assign name="violationsList" select="/ResultsSession/CodingStandards/StdViols/*[not(@supp='true') and (@locType=$locType) and (@locFile=$location)]"/>
        </xsl:if>
        <xsl:if test="$locType = 'rmt'">
            <saxon:assign name="violationsList" select="/ResultsSession/CodingStandards/StdViols/*[not(@supp='true') and (@locType=$locType) and (@uri=$location)]"/>
        </xsl:if>
   
        <xsl:for-each select="$violationsList">
            <xsl:sort select='@ln' data-type='number'/>
            <xsl:variable name="fileName" select="@resFile" saxon:assignable="yes"/>    
            <xsl:if test="string-length(@locFile) > 0">
                <saxon:assign name="fileName" select="@locFile"/>
            </xsl:if>     
            <xsl:if test="string-length(@uri) > 0">
                <saxon:assign name="fileName" select="@uri"/>
            </xsl:if>     
    
            <xsl:variable name="rule" select="@rule"/>
            <xsl:variable name="sev" select="@sev"/>
            <xsl:variable name="index" select="position()" saxon:assignable="yes"/>
            <xsl:variable name="violationID" saxon:assignable="yes"/>
            <saxon:assign name="violationID">
                <xsl:text>ViolId</xsl:text>
                <xsl:value-of select="$globalViolationIndex"/>
                <saxon:assign name="globalViolationIndex" select="$globalViolationIndex+ 1"/>
            </saxon:assign>
            
            <tr valign="bottom">
            <xsl:if test="((local-name()='FlowViol') or (local-name()='DupViol')) and not(($report_type) = ($email_report))">
                <xsl:attribute name="id"><xsl:value-of select="($violationID)"/>H</xsl:attribute>
                <xsl:attribute name="style">cursor:pointer</xsl:attribute>
                <xsl:attribute name="onclick">javascript:expandViolaion(&#39;<xsl:value-of select="($violationID)"/>H&#39;,&#39;<xsl:value-of select="($violationID)"/>&#39;, &#39;1&#39;)</xsl:attribute>
            </xsl:if>

            <td width="2%"></td>
            <td width="1%" align="right">
            <xsl:if test="(local-name()='FlowViol' or local-name()='DupViol') and not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <font class="gray"><span>+</span></font>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            </xsl:if>
            </td>
            <td width="2%" align="right" valign="top">
            <xsl:variable name="ln" select="@ln"/>
            <xsl:if test="not($ln = '-1')"> 
                <font class="gray"><xsl:value-of select="($ln)"/>:<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></font>
            </xsl:if>
            </td><td valign="top" class="tree">
		            
		    <span style="white-space: pre-wrap;">
		    <xsl:variable name="msg" select="@msg"/>
		    <xsl:choose>
			    <xsl:when test="string-length($msg) > 2000">
				    <xsl:value-of select="substring($msg, 1, 2000)"/> (...)
				</xsl:when>
				<xsl:otherwise>
				    <xsl:value-of select="$msg"/>
			    </xsl:otherwise>
		    </xsl:choose>
		    </span>
		    
            <xsl:variable name="rev" select="@rev"/>
            <xsl:if test="(string-length($rev) > 0) and not($rev = 'unknown.revision')">
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <font class="gray"><xsl:value-of select="$RES_PARAMETER_REVISION"/></font>
                <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
                <font class="gray"><xsl:value-of select="($rev)"/></font>
            </xsl:if>
            </td><td valign="top" width="10%" nowrap="nowrap">

               <xsl:variable name="auth" select="@auth"/>
               <xsl:variable name="authid" select="/ResultsSession/Authors/Author[@name=($auth)]/@id"/>
            
               <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
               <xsl:call-template name="custom_standards_author_link">
                  <xsl:with-param name="auth" select="($auth)"/>
                  <xsl:with-param name="authid" select="($authid)"/>
                  <xsl:with-param name="hasAuthorTasks" select="'true'"/>
                  <xsl:with-param name="hasAuthorSuppressions" select="'false'"/>
                  <xsl:with-param name="link_class">gray_link</xsl:with-param>
                  <xsl:with-param name="font_class">gray2</xsl:with-param>
               </xsl:call-template>
               <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
            
            </td><td align="right" valign="top" width="10%" nowrap="nowrap">
               <xsl:call-template name="standards_rule_link">
                  <xsl:with-param name="rule" select="($rule)"/>
                  <xsl:with-param name="sev" select="($sev)"/>
               </xsl:call-template>
            </td></tr>
            <saxon:assign name="globalIndex" select="$globalIndex+ 1"/>            
            <xsl:if test="local-name()='FlowViol'">                                    
               <xsl:call-template name="bd_dump_path">
                  <xsl:with-param name="checkedFilesStyle">true</xsl:with-param>
                <xsl:with-param name="violationID" select="$violationID"/>
                  </xsl:call-template>
            </xsl:if>
            <xsl:if test="(local-name()='DupViol')">
               <xsl:call-template name="dup_path">
                  <xsl:with-param name="checkedFilesStyle">true</xsl:with-param>
                  <xsl:with-param name="violationID" select="$violationID"/>
               </xsl:call-template>                    
            </xsl:if>             
        </xsl:for-each>
    </xsl:template>
    
    <!-- =================  dup violation path locations ============================ -->
    
    <xsl:template name="dup_path">
      <xsl:param name="checkedFilesStyle"/>
      <xsl:param name="violationID"/>
      <xsl:variable name="violStyle" saxon:assignable="yes"/>
      <xsl:if test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">
            <saxon:assign name="violStyle">
                  <xsl:text>display:none</xsl:text>
            </saxon:assign>
      </xsl:if>
      <xsl:variable name="bgColor" saxon:assignable="yes"/>
      <xsl:choose>
            <xsl:when test="not(($report_type) = ($email_report)) and not($report_format_mode='pdf')">
                  <saxon:assign name="bgColor">
                        <xsl:text>#F5F5F5</xsl:text>
                  </saxon:assign>
            </xsl:when>
            <xsl:otherwise>
                  <saxon:assign name="bgColor">
                        <xsl:text>#FFFFFF</xsl:text>
                  </saxon:assign>
            </xsl:otherwise>
      </xsl:choose>     
      
      <xsl:variable name="colSpan" saxon:assignable="yes" />

      <tr id="{$violationID}" style="{$violStyle}">

      <xsl:if test="($checkedFilesStyle = 'true')">
        <saxon:assign name="colSpan">3</saxon:assign>
        <td style="padding-left:10px" class="tree"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td>
        <td bgcolor="{$bgColor}"></td>
        <td bgcolor="{$bgColor}" class="tree"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td>
      </xsl:if>
      <xsl:if test="($checkedFilesStyle = 'false')">
        <saxon:assign name="colSpan">2</saxon:assign>
        <td bgcolor="{$bgColor}" style="padding-left:10px" class="tree"><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></td>
        <td bgcolor="{$bgColor}"></td>
      </xsl:if>

      <td bgcolor="{$bgColor}" style="padding-right:10px" colspan="{$colSpan}" class="tree">
        <pre style="margin:0px;">
        <xsl:for-each select="ElDescList/ElDesc[string-length(@supp)=0]">
          <xsl:if test="(position() != 1)">
            <xsl:text>&#xa;</xsl:text>
          </xsl:if>
          <xsl:value-of select="@desc"/>
        </xsl:for-each>
        </pre>
      </td>
      </tr>
    </xsl:template>
    
    <!-- =================  standards details supp messages (6) ============================ -->
    
    <xsl:template name="standards_details_supp_messages">
       <xsl:param name="location"/>
       
       <xsl:variable name="supp_msgs" saxon:assignable="yes">0</xsl:variable>
       <xsl:for-each select="/ResultsSession/CodingStandards/Supps/Supp[@suppLoc=($location)]">
          <xsl:variable name="ref_id" select="@refId"/>
          <xsl:variable name="single_suppr_msgs"
             select="count(/ResultsSession/CodingStandards/StdViols/*[@suppRef=($ref_id) and @supp='true'])"/>
          <saxon:assign name="supp_msgs" select="$supp_msgs + $single_suppr_msgs"/>
       </xsl:for-each>
       
       <xsl:if test="($report.developer_errors = 'true') and ($report.suppressed_msgs = 'true')">
       <tr><td colspan="5"><b><xsl:value-of select="$RES_PARAMETER_SUPPRESSIONS"/></b>:<xsl:value-of select="($nbsp)"
           disable-output-escaping="yes"/><xsl:value-of select="($supp_msgs)"/></td></tr>
       </xsl:if>
    
       <xsl:for-each select="/ResultsSession/CodingStandards/Supps/Supp[@suppLoc=($location)]">
       <xsl:sort select="@suppLoc"/>

       <xsl:variable name="id" select="@suppRule"/>
       <xsl:variable name="msg" select="@suppMsg"/>
       <xsl:variable name="reason" select="@suppRsn"/>
       <xsl:variable name="line" select="@suppLine"/>
       <xsl:variable name="auth" select="@suppAuth"/>
       <xsl:variable name="authid" select="/ResultsSession/Authors/Author[@name=($auth)]/@id"/>
    
       <xsl:variable name="ref_id" select="@refId"/>
       <xsl:for-each select="/ResultsSession/CodingStandards/StdViols/*[@suppRef=($ref_id) and @supp='true']">
    
       <tr valign="top">
       <td width="2%"></td>
       <td width="1%"></td>
       <td width="2%" align="right" >
               <font class="gray"><xsl:value-of select="($line)"/>:<xsl:value-of select="($nbsp)" disable-output-escaping="yes"/></font>
       </td>
       <td>
           <xsl:value-of select="($msg)"/>
            <xsl:if test="string-length($reason) > 0">             
                 <br/>
                 <font class="gray"><xsl:value-of select="$RES_PARAMETER_REASON"/></font><xsl:value-of select="($nbsp)" disable-output-escaping="yes"/><xsl:value-of select="($reason)"/>
           </xsl:if>
       </td>
              

       <td width="10%" nowrap="nowrap" class="tree">
       
       <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       <xsl:call-template name="custom_standards_author_link">
          <xsl:with-param name="auth" select="($auth)"/>
          <xsl:with-param name="authid" select="($authid)"/>
          <xsl:with-param name="hasAuthorTasks" select="'false'"/>
          <xsl:with-param name="hasAuthorSuppressions" select="boolean($supp_msgs > 0)"/>
          <xsl:with-param name="link_class">gray_link</xsl:with-param>
          <xsl:with-param name="font_class">gray2</xsl:with-param>
       </xsl:call-template>
       <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       
       </td><td align="right" width="10%" nowrap="nowrap" class="tree">
       <font class="gray"><xsl:value-of select="($id)"/></font>
       </td></tr>
       </xsl:for-each>
       </xsl:for-each>
    </xsl:template>
    
    <!-- =================  print author's link for standards ============================ -->

    <xsl:template name="standards_author_link">
       <xsl:param name="auth"/>
       <xsl:param name="authid"/>
       <xsl:param name="hasAuthorRecommendedTasks"/>
       <xsl:param name="hasAuthorTasks"/>
       <xsl:param name="hasAuthorSuppressions"/>

       <xsl:variable name="link_class" saxon:assignable="yes">blue_link</xsl:variable>
       <xsl:variable name="font_class" saxon:assignable="yes">black</xsl:variable>
        
       <!--xsl:if test="not($hasAuthorRecommendedTasks = 'true')">
          <saxon:assign name="link_class">green_link</saxon:assign>
          <saxon:assign name="font_class">green</saxon:assign>
       </xsl:if-->
       
       <xsl:call-template name="custom_standards_author_link">
          <xsl:with-param name="auth" select="($auth)"/>
          <xsl:with-param name="authid" select="($authid)"/>
          <xsl:with-param name="hasAuthorTasks" select="$hasAuthorTasks"/>
          <xsl:with-param name="hasAuthorSuppressions" select="$hasAuthorSuppressions"/>
          <xsl:with-param name="link_class" select="$link_class"/>
          <xsl:with-param name="font_class" select="$font_class"/>
       </xsl:call-template>
       
    </xsl:template>
    
    <!-- =================  print custom author's link for standards ============================ -->
    
    <xsl:template name="custom_standards_author_link">
       <xsl:param name="auth"/>
       <xsl:param name="authid"/>
       <xsl:param name="hasAuthorTasks"/>
       <xsl:param name="hasAuthorSuppressions"/>
       <xsl:param name="link_class"/>
       <xsl:param name="font_class"/>
       
       <xsl:if test="(($hasAuthorTasks) or ($hasAuthorSuppressions)) = 'true'">
    
       <xsl:if test="(($report.developer_reports) = 'true') and (not(($report_type) = ($email_report)) or ($report_format_mode='pdf'))">   
          <xsl:variable name="author_html" select="concat($dev_reports_prefix,$authid,'.html#cst_',$authid)"/>
          <xsl:variable name="href" saxon:assignable="yes" select="concat('javascript:openWin(',$qt,$author_html,$qt,')')"/>
          <xsl:if test="($report_type) = ($tcm_report)">
             <xsl:variable name="dev_rep_name" select="concat($dev_reports_prefix,$authid,'.html')"/>
             <saxon:assign name="href" select="concat('javascript:openDevReport(',$qt,$dev_rep_name,$qt,')')"/>
          </xsl:if>
          <xsl:call-template name="standard_link_ref">
             <xsl:with-param name="href" select="($href)"/>
             <xsl:with-param name="label" select="($auth)"/>
             <xsl:with-param name="class" select="($link_class)"/>
          </xsl:call-template>       
       </xsl:if>
    
       <xsl:if test="(($report.developer_errors) = 'true') and ((($report.developer_reports) = 'false') or (($report_type) = ($email_report)))">
             <xsl:if test="not($report_format_mode='pdf')">
               <xsl:if test="($hasAuthorTasks) = 'true'">
                 <a class="{$link_class}" href="#cs_{$authid}"><xsl:value-of select="($auth)"/></a>
              </xsl:if>
              <xsl:if test="not(($hasAuthorTasks) = 'true')">
                 <a class="{$link_class}" href="#supp_{$authid}"><xsl:value-of select="($auth)"/></a>
              </xsl:if>
          </xsl:if>
          <xsl:if test="($report_format_mode='pdf') and (($report.developer_reports = 'false') or not(($report_type) = ($email_report)))">
              <font class="{$font_class}"><xsl:value-of select="($auth)"/></font>
          </xsl:if>
       </xsl:if>
         
       <xsl:if test="(($report.developer_errors) = 'false') and (($report.developer_reports = 'false') or (($report_type) = ($email_report))) and not($report_format_mode='pdf')">
          <font class="{$font_class}"><xsl:value-of select="($auth)"/></font>
       </xsl:if>
       
       <xsl:if test="($report.developer_errors = 'false') and ($report.developer_reports = 'false') and ($report_format_mode='pdf')">
          <font class="{$font_class}"><xsl:value-of select="($auth)"/></font>
       </xsl:if>
       
       </xsl:if>
       
       <xsl:if test="not((($hasAuthorTasks) or ($hasAuthorSuppressions)) = 'true')">
          <font class="{$font_class}"><xsl:value-of select="($auth)"/></font>
       </xsl:if>
    
    </xsl:template>

    <!-- =================  print rule's link ============================ -->

    <xsl:template name="standards_rule_link">
       <xsl:param name="rule"/>
       <xsl:param name="sev"/>
       
       <xsl:variable name="label" select="concat($rule,'-',$sev)"/>
       <xsl:if test="string-length($rules_dir_path) > 0">
          <xsl:variable name="rule_html"
               select="concat('javascript:openWin(',$qt,$rules_dir_path,$rule,'.html',$qt,')')"/>
          <xsl:call-template name="standard_link_ref">
             <xsl:with-param name="href" select="($rule_html)"/>
             <xsl:with-param name="label" select="($label)"/>
             <xsl:with-param name="class">gray_link</xsl:with-param>
          </xsl:call-template>
       </xsl:if>
       <xsl:if test="string-length($rules_dir_path) = 0">
          <font class="gray"><xsl:value-of select="($label)"/></font>
       </xsl:if>
    
    </xsl:template>    
         	
    <!-- =================  print rule's and category's link in tree ============================ -->

    <xsl:template name="standards_rule_link_in_tree">
       <xsl:param name="id"/>
       <xsl:param name="sev"/>

       <xsl:variable name="label" saxon:assignable="yes"></xsl:variable>

       <xsl:if test="string-length($sev) > 0">
            <saxon:assign name="label" select="concat('(',$id,'-',$sev,')')"/>
       </xsl:if>
       <xsl:if test="string-length($sev) = 0">
            <saxon:assign name="label" select="concat('(',$id,')')"/>
       </xsl:if>
    
       <xsl:if test="string-length($rules_dir_path) > 0">
          <xsl:variable name="rule_html" 
            select="concat('javascript:openWin(',$qt,$rules_dir_path,$id,'.html',$qt,')')"/>
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          <xsl:call-template name="standard_link_ref">
             <xsl:with-param name="href" select="($rule_html)"/>
             <xsl:with-param name="label" select="($label)"/>
             <xsl:with-param name="class">gray_link</xsl:with-param>
          </xsl:call-template>
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       </xsl:if>
       <xsl:if test="string-length($rules_dir_path) = 0">
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
          <font class="gray">
             <xsl:value-of select="($label)"/>
          </font>
          <xsl:value-of select="($nbsp)" disable-output-escaping="yes"/>
       </xsl:if>
    
    </xsl:template>    
         	
</xsl:stylesheet> 